[Libreoffice-commits] core.git: basegfx/source basic/source connectivity/source cppcanvas/source drawinglayer/source editeng/source filter/source framework/inc framework/source include/basegfx include/registry include/sfx2 include/svtools include/toolkit include/tools include/vcl lingucomponent/source reportdesign/source sax/qa setup_native/source sfx2/source shell/inc shell/source svl/source svtools/source test/source testtools/source toolkit/source tools/source ucb/source vcl/source vcl/workben xmloff/source

Caolán McNamara caolanm at redhat.com
Wed Mar 4 05:08:24 PST 2015


 basegfx/source/matrix/b3dhommatrix.cxx                                   |    8 
 basic/source/inc/dlgcont.hxx                                             |    6 
 basic/source/inc/namecont.hxx                                            |    4 
 basic/source/inc/scriptcont.hxx                                          |    6 
 basic/source/uno/dlgcont.cxx                                             |   10 
 basic/source/uno/scriptcont.cxx                                          |   12 -
 connectivity/source/commontools/sqlerror.cxx                             |    6 
 cppcanvas/source/inc/implrenderer.hxx                                    |    4 
 drawinglayer/source/dumper/XShapeDumper.cxx                              |  114 +++++-----
 drawinglayer/source/primitive2d/metafileprimitive2d.cxx                  |    6 
 editeng/source/editeng/impedit.hxx                                       |   12 -
 editeng/source/editeng/impedit4.cxx                                      |   36 +--
 filter/source/graphicfilter/eos2met/eos2met.cxx                          |   12 -
 framework/inc/services/layoutmanager.hxx                                 |    2 
 framework/source/layoutmanager/layoutmanager.cxx                         |    4 
 include/basegfx/matrix/b3dhommatrix.hxx                                  |    2 
 include/registry/reflwrit.hxx                                            |   12 -
 include/sfx2/dinfdlg.hxx                                                 |    6 
 include/sfx2/docfile.hxx                                                 |    2 
 include/svtools/ctrlbox.hxx                                              |    4 
 include/toolkit/helper/vclunohelper.hxx                                  |    2 
 include/tools/b3dtrans.hxx                                               |    6 
 include/tools/simplerm.hxx                                               |    2 
 include/vcl/longcurr.hxx                                                 |   14 -
 include/vcl/taskpanelist.hxx                                             |    2 
 include/vcl/toolbox.hxx                                                  |    2 
 lingucomponent/source/languageguessing/guess.cxx                         |    5 
 lingucomponent/source/languageguessing/guess.hxx                         |    2 
 lingucomponent/source/languageguessing/simpleguesser.cxx                 |    6 
 lingucomponent/source/languageguessing/simpleguesser.hxx                 |    6 
 reportdesign/source/ui/dlg/CondFormat.cxx                                |    4 
 reportdesign/source/ui/inc/CondFormat.hxx                                |    4 
 sax/qa/cppunit/test_converter.cxx                                        |    2 
 setup_native/source/win32/customactions/shellextensions/vistaspecial.cxx |   13 -
 sfx2/source/doc/docfile.cxx                                              |    4 
 shell/inc/internal/metainforeader.hxx                                    |    8 
 shell/inc/internal/thumbviewer.hxx                                       |    2 
 shell/source/win32/ooofilereader/autostyletag.cxx                        |    2 
 shell/source/win32/ooofilereader/autostyletag.hxx                        |    2 
 shell/source/win32/ooofilereader/metainforeader.cxx                      |   10 
 shell/source/win32/shlxthandler/shlxthdl.cxx                             |    4 
 shell/source/win32/shlxthandler/thumbviewer/thumbviewer.cxx              |    2 
 svl/source/inc/passwordcontainer.hxx                                     |    2 
 svl/source/passwordcontainer/passwordcontainer.cxx                       |    7 
 svtools/source/control/ctrlbox.cxx                                       |    4 
 test/source/primitive2dxmldump.cxx                                       |    4 
 testtools/source/bridgetest/cppobj.cxx                                   |    4 
 toolkit/source/controls/grid/gridcolumn.cxx                              |    2 
 toolkit/source/controls/grid/gridcolumn.hxx                              |    4 
 toolkit/source/helper/vclunohelper.cxx                                   |    2 
 tools/source/generic/b3dtrans.cxx                                        |    4 
 tools/source/rc/resmgr.cxx                                               |    4 
 ucb/source/ucp/cmis/cmis_content.cxx                                     |   14 -
 ucb/source/ucp/cmis/cmis_content.hxx                                     |    2 
 vcl/source/control/longcurr.cxx                                          |   16 -
 vcl/source/opengl/OpenGLContext.cxx                                      |    4 
 vcl/source/window/taskpanelist.cxx                                       |    4 
 vcl/source/window/toolbox.cxx                                            |    2 
 vcl/workben/vcldemo.cxx                                                  |    6 
 xmloff/source/chart/SchXMLAxisContext.cxx                                |    8 
 60 files changed, 226 insertions(+), 239 deletions(-)

New commits:
commit 32f95a35514701ed16413125b440c16d90f52b4a
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Wed Mar 4 09:28:31 2015 +0000

    V813: Decreased performance
    
    Change-Id: I8a7528366156b288dc422b09cff0d5a32cde3c91

diff --git a/basegfx/source/matrix/b3dhommatrix.cxx b/basegfx/source/matrix/b3dhommatrix.cxx
index 9233875..75ba78f 100644
--- a/basegfx/source/matrix/b3dhommatrix.cxx
+++ b/basegfx/source/matrix/b3dhommatrix.cxx
@@ -337,14 +337,14 @@ namespace basegfx
         mpImpl->doMulMatrix(aOrthoMat);
     }
 
-    void B3DHomMatrix::orientation(B3DPoint aVRP, B3DVector aVPN, B3DVector aVUV)
+    void B3DHomMatrix::orientation(const B3DPoint& rVRP, B3DVector aVPN, B3DVector aVUV)
     {
         Impl3DHomMatrix aOrientationMat;
 
         // translate -VRP
-        aOrientationMat.set(0, 3, -aVRP.getX());
-        aOrientationMat.set(1, 3, -aVRP.getY());
-        aOrientationMat.set(2, 3, -aVRP.getZ());
+        aOrientationMat.set(0, 3, -rVRP.getX());
+        aOrientationMat.set(1, 3, -rVRP.getY());
+        aOrientationMat.set(2, 3, -rVRP.getZ());
 
         // build rotation
         aVUV.normalize();
diff --git a/basic/source/inc/dlgcont.hxx b/basic/source/inc/dlgcont.hxx
index baf3da8..13a10dc 100644
--- a/basic/source/inc/dlgcont.hxx
+++ b/basic/source/inc/dlgcont.hxx
@@ -40,8 +40,8 @@ class SfxDialogLibraryContainer : public SfxLibraryContainer
     virtual SfxLibrary* SAL_CALL implCreateLibraryLink
         ( const OUString& aName, const OUString& aLibInfoFileURL,
           const OUString& StorageURL, bool ReadOnly ) SAL_OVERRIDE;
-    virtual ::com::sun::star::uno::Any SAL_CALL createEmptyLibraryElement( void ) SAL_OVERRIDE;
-    virtual bool SAL_CALL isLibraryElementValid( ::com::sun::star::uno::Any aElement ) const SAL_OVERRIDE;
+    virtual ::com::sun::star::uno::Any SAL_CALL createEmptyLibraryElement() SAL_OVERRIDE;
+    virtual bool SAL_CALL isLibraryElementValid(const css::uno::Any& rElement) const SAL_OVERRIDE;
     virtual void SAL_CALL writeLibraryElement
     (
         const ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameContainer>& xLibrary,
@@ -154,7 +154,7 @@ public:
     static bool containsValidDialog( const ::com::sun::star::uno::Any& aElement );
 
 protected:
-    virtual bool SAL_CALL isLibraryElementValid( ::com::sun::star::uno::Any aElement ) const SAL_OVERRIDE;
+    virtual bool SAL_CALL isLibraryElementValid(const css::uno::Any& rElement) const SAL_OVERRIDE;
 };
 
 }   // namespace basic
diff --git a/basic/source/inc/namecont.hxx b/basic/source/inc/namecont.hxx
index 2295231..d699805 100644
--- a/basic/source/inc/namecont.hxx
+++ b/basic/source/inc/namecont.hxx
@@ -294,7 +294,7 @@ protected:
         ( const OUString& aName, const OUString& aLibInfoFileURL,
           const OUString& StorageURL, bool ReadOnly ) = 0;
     virtual ::com::sun::star::uno::Any SAL_CALL createEmptyLibraryElement( void ) = 0;
-    virtual bool SAL_CALL isLibraryElementValid( ::com::sun::star::uno::Any aElement ) const = 0;
+    virtual bool SAL_CALL isLibraryElementValid(const css::uno::Any& rElement) const = 0;
     virtual void SAL_CALL writeLibraryElement
     (
         const ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameContainer>& xLibrary,
@@ -715,7 +715,7 @@ public:
 protected:
     virtual bool isLoadedStorable();
 
-    virtual bool SAL_CALL isLibraryElementValid( ::com::sun::star::uno::Any aElement ) const = 0;
+    virtual bool SAL_CALL isLibraryElementValid(const css::uno::Any& rElement) const = 0;
 };
 
 
diff --git a/basic/source/inc/scriptcont.hxx b/basic/source/inc/scriptcont.hxx
index 75f65e3..30c8c62 100644
--- a/basic/source/inc/scriptcont.hxx
+++ b/basic/source/inc/scriptcont.hxx
@@ -40,8 +40,8 @@ class SfxScriptLibraryContainer : public SfxLibraryContainer, public OldBasicPas
     virtual SfxLibrary* SAL_CALL implCreateLibraryLink
         ( const OUString& aName, const OUString& aLibInfoFileURL,
           const OUString& StorageURL, bool ReadOnly ) SAL_OVERRIDE;
-    virtual ::com::sun::star::uno::Any SAL_CALL createEmptyLibraryElement( void ) SAL_OVERRIDE;
-    virtual bool SAL_CALL isLibraryElementValid( ::com::sun::star::uno::Any aElement ) const SAL_OVERRIDE;
+    virtual ::com::sun::star::uno::Any SAL_CALL createEmptyLibraryElement() SAL_OVERRIDE;
+    virtual bool SAL_CALL isLibraryElementValid(const css::uno::Any& rElement) const SAL_OVERRIDE;
     virtual void SAL_CALL writeLibraryElement
     (
         const ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameContainer>& xLibrary,
@@ -176,7 +176,7 @@ public:
     static bool containsValidModule( const ::com::sun::star::uno::Any& _rElement );
 
 protected:
-    virtual bool SAL_CALL isLibraryElementValid( ::com::sun::star::uno::Any aElement ) const SAL_OVERRIDE;
+    virtual bool SAL_CALL isLibraryElementValid(const css::uno::Any& rElement) const SAL_OVERRIDE;
 };
 
 
diff --git a/basic/source/uno/dlgcont.cxx b/basic/source/uno/dlgcont.cxx
index 39dde70..5876bed 100644
--- a/basic/source/uno/dlgcont.cxx
+++ b/basic/source/uno/dlgcont.cxx
@@ -98,7 +98,7 @@ SfxLibrary* SfxDialogLibraryContainer::implCreateLibraryLink
     return pRet;
 }
 
-Any SAL_CALL SfxDialogLibraryContainer::createEmptyLibraryElement( void )
+Any SAL_CALL SfxDialogLibraryContainer::createEmptyLibraryElement()
 {
     Reference< XInputStreamProvider > xISP;
     Any aRetAny;
@@ -106,9 +106,9 @@ Any SAL_CALL SfxDialogLibraryContainer::createEmptyLibraryElement( void )
     return aRetAny;
 }
 
-bool SAL_CALL SfxDialogLibraryContainer::isLibraryElementValid( Any aElement ) const
+bool SAL_CALL SfxDialogLibraryContainer::isLibraryElementValid(const Any& rElement) const
 {
-    return SfxDialogLibrary::containsValidDialog( aElement );
+    return SfxDialogLibrary::containsValidDialog(rElement);
 }
 
 bool writeOasis2OOoLibraryElement(
@@ -575,9 +575,9 @@ bool SfxDialogLibrary::containsValidDialog( const ::com::sun::star::uno::Any& aE
     return xISP.is();
 }
 
-bool SAL_CALL SfxDialogLibrary::isLibraryElementValid( ::com::sun::star::uno::Any aElement ) const
+bool SAL_CALL SfxDialogLibrary::isLibraryElementValid(const css::uno::Any& rElement) const
 {
-    return SfxDialogLibrary::containsValidDialog( aElement );
+    return SfxDialogLibrary::containsValidDialog(rElement);
 }
 
 }
diff --git a/basic/source/uno/scriptcont.cxx b/basic/source/uno/scriptcont.cxx
index eeb68f0..7d67085 100644
--- a/basic/source/uno/scriptcont.cxx
+++ b/basic/source/uno/scriptcont.cxx
@@ -168,9 +168,9 @@ Any SAL_CALL SfxScriptLibraryContainer::createEmptyLibraryElement( void )
     return aRetAny;
 }
 
-bool SAL_CALL SfxScriptLibraryContainer::isLibraryElementValid( Any aElement ) const
+bool SAL_CALL SfxScriptLibraryContainer::isLibraryElementValid(const Any& rElement) const
 {
-    return SfxScriptLibrary::containsValidModule( aElement );
+    return SfxScriptLibrary::containsValidModule(rElement);
 }
 
 void SAL_CALL SfxScriptLibraryContainer::writeLibraryElement( const Reference < XNameContainer >& xLib,
@@ -1268,16 +1268,16 @@ void SfxScriptLibrary::storeResourcesToStorage( const ::com::sun::star::uno::Ref
     (void)xStorage;
 }
 
-bool SfxScriptLibrary::containsValidModule( const Any& aElement )
+bool SfxScriptLibrary::containsValidModule(const Any& rElement)
 {
     OUString sModuleText;
-    aElement >>= sModuleText;
+    rElement >>= sModuleText;
     return ( !sModuleText.isEmpty() );
 }
 
-bool SAL_CALL SfxScriptLibrary::isLibraryElementValid( ::com::sun::star::uno::Any aElement ) const
+bool SAL_CALL SfxScriptLibrary::isLibraryElementValid(const css::uno::Any& rElement) const
 {
-    return SfxScriptLibrary::containsValidModule( aElement );
+    return SfxScriptLibrary::containsValidModule(rElement);
 }
 
 IMPLEMENT_FORWARD_XINTERFACE2( SfxScriptLibrary, SfxLibrary, SfxScriptLibrary_BASE );
diff --git a/connectivity/source/commontools/sqlerror.cxx b/connectivity/source/commontools/sqlerror.cxx
index 37c4e65..fa5f4c0 100644
--- a/connectivity/source/commontools/sqlerror.cxx
+++ b/connectivity/source/commontools/sqlerror.cxx
@@ -124,17 +124,17 @@ namespace connectivity
 
         /** substitutes a given placeholder in the given message with the given value
         */
-        void    lcl_substitutePlaceholder( OUString& _rMessage, const sal_Char* _pPlaceholder, ParamValue _rParamValue )
+        void lcl_substitutePlaceholder(OUString& _rMessage, const sal_Char* _pPlaceholder, const ParamValue& rParamValue)
         {
             size_t nPlaceholderLen( strlen( _pPlaceholder ) );
             sal_Int32 nIndex = _rMessage.indexOfAsciiL( _pPlaceholder, nPlaceholderLen );
 
             bool bHasPlaceholder = ( nIndex != -1 );
-            bool bWantsPlaceholder = _rParamValue.is();
+            bool bWantsPlaceholder = rParamValue.is();
             OSL_ENSURE( bHasPlaceholder == bWantsPlaceholder, "lcl_substitutePlaceholder: placeholder where none is expected, or no placeholder where one is needed!" );
 
             if ( bHasPlaceholder && bWantsPlaceholder )
-                _rMessage = _rMessage.replaceAt( nIndex, nPlaceholderLen, *_rParamValue );
+                _rMessage = _rMessage.replaceAt( nIndex, nPlaceholderLen, *rParamValue );
         }
 
 
diff --git a/cppcanvas/source/inc/implrenderer.hxx b/cppcanvas/source/inc/implrenderer.hxx
index 3d18a35..1aa88f1 100644
--- a/cppcanvas/source/inc/implrenderer.hxx
+++ b/cppcanvas/source/inc/implrenderer.hxx
@@ -106,7 +106,7 @@ namespace cppcanvas
                 eDy  = dy;
             }
 
-            void Set (XForm f)
+            void Set (const XForm& f)
             {
                 eM11 = f.eM11;
                 eM12 = f.eM12;
@@ -126,7 +126,7 @@ namespace cppcanvas
                 eDy *= eDx*m12  + eDy*m22 + dy;
             }
 
-            void Multiply (XForm f)
+            void Multiply (const XForm& f)
             {
                 eM11 = eM11*f.eM11 + eM12*f.eM21;
                 eM12 = eM11*f.eM12 + eM12*f.eM22;
diff --git a/drawinglayer/source/dumper/XShapeDumper.cxx b/drawinglayer/source/dumper/XShapeDumper.cxx
index 62c3470..d4d7f25 100644
--- a/drawinglayer/source/dumper/XShapeDumper.cxx
+++ b/drawinglayer/source/dumper/XShapeDumper.cxx
@@ -34,9 +34,9 @@ namespace {
 // FUNCTION DECLARATIONS
 
 // auxiliary functions
-void dumpGradientProperty(com::sun::star::awt::Gradient aGradient, xmlTextWriterPtr xmlWriter);
-void dumpPolyPolygonBezierCoords(com::sun::star::drawing::PolyPolygonBezierCoords aPolyPolygonBezierCoords, xmlTextWriterPtr xmlWriter);
-void dumpPointSequenceSequence(const com::sun::star::drawing::PointSequenceSequence& aPointSequenceSequence, uno::Sequence<uno::Sequence<drawing::PolygonFlags> >*, xmlTextWriterPtr xmlWriter);
+void dumpGradientProperty(const css::awt::Gradient& rGradient, xmlTextWriterPtr xmlWriter);
+void dumpPolyPolygonBezierCoords(const css::drawing::PolyPolygonBezierCoords& rPolyPolygonBezierCoords, xmlTextWriterPtr xmlWriter);
+void dumpPointSequenceSequence(const com::sun::star::drawing::PointSequenceSequence& rPointSequenceSequence, const uno::Sequence<uno::Sequence<drawing::PolygonFlags> >*, xmlTextWriterPtr xmlWriter);
 void dumpPropertyValueAsElement(const beans::PropertyValue& rPropertyValue, xmlTextWriterPtr xmlWriter);
 
 // FillProperties.idl
@@ -44,10 +44,10 @@ void dumpFillStyleAsAttribute(com::sun::star::drawing::FillStyle eFillStyle, xml
 void dumpFillColorAsAttribute(sal_Int32 aColor, xmlTextWriterPtr xmlWriter);
 void dumpFillTransparenceAsAttribute(sal_Int32 aTransparence, xmlTextWriterPtr xmlWriter);
 void dumpFillTransparenceGradientNameAsAttribute(const OUString& sTranspGradName, xmlTextWriterPtr xmlWriter);
-void dumpFillTransparenceGradientAsElement(com::sun::star::awt::Gradient aTranspGrad, xmlTextWriterPtr xmlWriter);
+void dumpFillTransparenceGradientAsElement(const css::awt::Gradient& rTranspGrad, xmlTextWriterPtr xmlWriter);
 void dumpFillGradientNameAsAttribute(const OUString& sGradName, xmlTextWriterPtr xmlWriter);
-void dumpFillGradientAsElement(com::sun::star::awt::Gradient aGradient, xmlTextWriterPtr xmlWriter);
-void dumpFillHatchAsElement(com::sun::star::drawing::Hatch aHatch, xmlTextWriterPtr xmlWriter);
+void dumpFillGradientAsElement(const css::awt::Gradient& rGradient, xmlTextWriterPtr xmlWriter);
+void dumpFillHatchAsElement(const css::drawing::Hatch& rHatch, xmlTextWriterPtr xmlWriter);
 void dumpFillBackgroundAsAttribute(bool bBackground, xmlTextWriterPtr xmlWriter);
 void dumpFillBitmapAsElement(com::sun::star::uno::Reference<com::sun::star::awt::XBitmap> xBitmap, xmlTextWriterPtr xmlWriter);
 void dumpFillBitmapURLAsAttribute(const OUString& sBitmapURL, xmlTextWriterPtr xmlWriter);
@@ -65,7 +65,7 @@ void dumpFillBitmapTileAsAttribute(bool bBitmapTile, xmlTextWriterPtr xmlWriter)
 
 // LineProperties.idl
 void dumpLineStyleAsAttribute(com::sun::star::drawing::LineStyle eLineStyle, xmlTextWriterPtr xmlWriter);
-void dumpLineDashAsElement(com::sun::star::drawing::LineDash aLineDash, xmlTextWriterPtr xmlWriter);
+void dumpLineDashAsElement(const css::drawing::LineDash& rLineDash, xmlTextWriterPtr xmlWriter);
 void dumpLineDashNameAsAttribute(const OUString& sLineDashName, xmlTextWriterPtr xmlWriter);
 void dumpLineColorAsAttribute(sal_Int32 aLineColor, xmlTextWriterPtr xmlWriter);
 void dumpLineTransparenceAsAttribute(sal_Int32 aLineTransparence, xmlTextWriterPtr xmlWriter);
@@ -73,8 +73,8 @@ void dumpLineWidthAsAttribute(sal_Int32 aLineWidth, xmlTextWriterPtr xmlWriter);
 void dumpLineJointAsAttribute(com::sun::star::drawing::LineJoint eLineJoint, xmlTextWriterPtr xmlWriter);
 void dumpLineStartNameAsAttribute(const OUString& sLineStartName, xmlTextWriterPtr xmlWriter);
 void dumpLineEndNameAsAttribute(const OUString& sLineEndName, xmlTextWriterPtr xmlWriter);
-void dumpLineStartAsElement(com::sun::star::drawing::PolyPolygonBezierCoords aLineStart, xmlTextWriterPtr xmlWriter);
-void dumpLineEndAsElement(com::sun::star::drawing::PolyPolygonBezierCoords aLineEnd, xmlTextWriterPtr xmlWriter);
+void dumpLineStartAsElement(const css::drawing::PolyPolygonBezierCoords& rLineStart, xmlTextWriterPtr xmlWriter);
+void dumpLineEndAsElement(const css::drawing::PolyPolygonBezierCoords& rLineEnd, xmlTextWriterPtr xmlWriter);
 void dumpLineStartCenterAsAttribute(bool bLineStartCenter, xmlTextWriterPtr xmlWriter);
 void dumpLineStartWidthAsAttribute(sal_Int32 aLineStartWidth, xmlTextWriterPtr xmlWriter);
 void dumpLineEndCenterAsAttribute(bool bLineEndCenter, xmlTextWriterPtr xmlWriter);
@@ -82,8 +82,8 @@ void dumpLineEndWidthAsAttribute(sal_Int32 aLineEndWidth, xmlTextWriterPtr xmlWr
 
 // PolyPolygonDescriptor.idl
 void dumpPolygonKindAsAttribute(com::sun::star::drawing::PolygonKind ePolygonKind, xmlTextWriterPtr xmlWriter);
-void dumpPolyPolygonAsElement(const com::sun::star::drawing::PointSequenceSequence& aPolyPolygon, xmlTextWriterPtr xmlWriter);
-void dumpGeometryAsElement(const com::sun::star::drawing::PointSequenceSequence& aGeometry, xmlTextWriterPtr xmlWriter);
+void dumpPolyPolygonAsElement(const com::sun::star::drawing::PointSequenceSequence& rPolyPolygon, xmlTextWriterPtr xmlWriter);
+void dumpGeometryAsElement(const com::sun::star::drawing::PointSequenceSequence& rGeometry, xmlTextWriterPtr xmlWriter);
 
 // CharacterProperties.idl
 void dumpCharHeightAsAttribute(float fHeight, xmlTextWriterPtr xmlWriter);
@@ -130,8 +130,8 @@ void dumpPrintableAsAttribute(bool bPrintable, xmlTextWriterPtr xmlWriter);
 void dumpMoveProtectAsAttribute(bool bMoveProtect, xmlTextWriterPtr xmlWriter);
 void dumpNameAsAttribute(const OUString& sName, xmlTextWriterPtr xmlWriter);
 void dumpSizeProtectAsAttribute(bool bSizeProtect, xmlTextWriterPtr xmlWriter);
-void dumpHomogenMatrixLine3(com::sun::star::drawing::HomogenMatrixLine3 aLine, xmlTextWriterPtr xmlWriter);
-void dumpTransformationAsElement(com::sun::star::drawing::HomogenMatrix3 const & aTransformation, xmlTextWriterPtr xmlWriter);
+void dumpHomogenMatrixLine3(const css::drawing::HomogenMatrixLine3& rLine, xmlTextWriterPtr xmlWriter);
+void dumpTransformationAsElement(const css::drawing::HomogenMatrix3& rTransformation, xmlTextWriterPtr xmlWriter);
 void dumpNavigationOrderAsAttribute(sal_Int32 aNavigationOrder, xmlTextWriterPtr xmlWriter);
 void dumpHyperlinkAsAttribute(const OUString& sHyperlink, xmlTextWriterPtr xmlWriter);
 void dumpInteropGrabBagAsElement(const uno::Sequence< beans::PropertyValue>& aInteropGrabBag, xmlTextWriterPtr xmlWriter);
@@ -218,9 +218,9 @@ void dumpFillTransparenceGradientNameAsAttribute(const OUString& sTranspGradName
 }
 
 //because there's more awt::Gradient properties to dump
-void dumpGradientProperty(awt::Gradient aGradient, xmlTextWriterPtr xmlWriter)
+void dumpGradientProperty(const awt::Gradient& rGradient, xmlTextWriterPtr xmlWriter)
 {
-    switch(aGradient.Style)   //enum GradientStyle
+    switch (rGradient.Style)   //enum GradientStyle
     {
         case awt::GradientStyle_LINEAR:
             xmlTextWriterWriteFormatAttribute( xmlWriter, BAD_CAST("style"), "%s", "LINEAR");
@@ -243,21 +243,21 @@ void dumpGradientProperty(awt::Gradient aGradient, xmlTextWriterPtr xmlWriter)
         default:
             break;
     }
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("startColor"), "%06x", (unsigned int) aGradient.StartColor);
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("endColor"), "%06x", (unsigned int) aGradient.EndColor);
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("angle"), "%" SAL_PRIdINT32, (sal_Int32) aGradient.Angle);
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("border"), "%" SAL_PRIdINT32, (sal_Int32) aGradient.Border);
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("xOffset"), "%" SAL_PRIdINT32, (sal_Int32) aGradient.XOffset);
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("yOffset"), "%" SAL_PRIdINT32, (sal_Int32) aGradient.YOffset);
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("startIntensity"), "%" SAL_PRIdINT32, (sal_Int32) aGradient.StartIntensity);
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("endIntensity"), "%" SAL_PRIdINT32, (sal_Int32) aGradient.EndIntensity);
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("stepCount"), "%" SAL_PRIdINT32, (sal_Int32) aGradient.StepCount);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("startColor"), "%06x", (unsigned int) rGradient.StartColor);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("endColor"), "%06x", (unsigned int) rGradient.EndColor);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("angle"), "%" SAL_PRIdINT32, (sal_Int32) rGradient.Angle);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("border"), "%" SAL_PRIdINT32, (sal_Int32) rGradient.Border);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("xOffset"), "%" SAL_PRIdINT32, (sal_Int32) rGradient.XOffset);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("yOffset"), "%" SAL_PRIdINT32, (sal_Int32) rGradient.YOffset);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("startIntensity"), "%" SAL_PRIdINT32, (sal_Int32) rGradient.StartIntensity);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("endIntensity"), "%" SAL_PRIdINT32, (sal_Int32) rGradient.EndIntensity);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("stepCount"), "%" SAL_PRIdINT32, (sal_Int32) rGradient.StepCount);
 }
 
-void dumpFillTransparenceGradientAsElement(awt::Gradient aTranspGrad, xmlTextWriterPtr xmlWriter)
+void dumpFillTransparenceGradientAsElement(const awt::Gradient& rTranspGrad, xmlTextWriterPtr xmlWriter)
 {
     xmlTextWriterStartElement(xmlWriter, BAD_CAST( "FillTransparenceGradient" ));
-    dumpGradientProperty(aTranspGrad, xmlWriter);
+    dumpGradientProperty(rTranspGrad, xmlWriter);
     xmlTextWriterEndElement( xmlWriter );
 }
 
@@ -267,17 +267,17 @@ void dumpFillGradientNameAsAttribute(const OUString& sGradName, xmlTextWriterPtr
         OUStringToOString(sGradName, RTL_TEXTENCODING_UTF8).getStr());
 }
 
-void dumpFillGradientAsElement(awt::Gradient aGradient, xmlTextWriterPtr xmlWriter)
+void dumpFillGradientAsElement(const awt::Gradient& rGradient, xmlTextWriterPtr xmlWriter)
 {
     xmlTextWriterStartElement(xmlWriter, BAD_CAST( "FillGradient" ));
-    dumpGradientProperty(aGradient, xmlWriter);
+    dumpGradientProperty(rGradient, xmlWriter);
     xmlTextWriterEndElement( xmlWriter );
 }
 
-void dumpFillHatchAsElement(drawing::Hatch aHatch, xmlTextWriterPtr xmlWriter)
+void dumpFillHatchAsElement(const drawing::Hatch& rHatch, xmlTextWriterPtr xmlWriter)
 {
     xmlTextWriterStartElement(xmlWriter, BAD_CAST( "FillHatch" ));
-    switch(aHatch.Style)
+    switch (rHatch.Style)
     {
         case drawing::HatchStyle_SINGLE:
             xmlTextWriterWriteFormatAttribute( xmlWriter, BAD_CAST("style"), "%s", "SINGLE");
@@ -291,9 +291,9 @@ void dumpFillHatchAsElement(drawing::Hatch aHatch, xmlTextWriterPtr xmlWriter)
         default:
             break;
     }
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("color"), "%06x", (unsigned int) aHatch.Color);
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("distance"), "%" SAL_PRIdINT32, (sal_Int32) aHatch.Distance);
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("angle"), "%" SAL_PRIdINT32, (sal_Int32) aHatch.Angle);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("color"), "%06x", (unsigned int) rHatch.Color);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("distance"), "%" SAL_PRIdINT32, (sal_Int32) rHatch.Distance);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("angle"), "%" SAL_PRIdINT32, (sal_Int32) rHatch.Angle);
     xmlTextWriterEndElement( xmlWriter );
 }
 
@@ -453,10 +453,10 @@ void dumpLineStyleAsAttribute(drawing::LineStyle eLineStyle, xmlTextWriterPtr xm
     }
 }
 
-void dumpLineDashAsElement(drawing::LineDash aLineDash, xmlTextWriterPtr xmlWriter)
+void dumpLineDashAsElement(const drawing::LineDash& rLineDash, xmlTextWriterPtr xmlWriter)
 {
     xmlTextWriterStartElement(xmlWriter, BAD_CAST( "LineDash" ));
-    switch(aLineDash.Style)
+    switch (rLineDash.Style)
     {
         case drawing::DashStyle_RECT:
             xmlTextWriterWriteFormatAttribute( xmlWriter, BAD_CAST("style"), "%s", "RECT");
@@ -473,11 +473,11 @@ void dumpLineDashAsElement(drawing::LineDash aLineDash, xmlTextWriterPtr xmlWrit
         default:
             break;
     }
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("dots"), "%" SAL_PRIdINT32, (sal_Int32) aLineDash.Dots);
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("dotLen"), "%" SAL_PRIdINT32, (sal_Int32) aLineDash.DotLen);
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("dashes"), "%" SAL_PRIdINT32, (sal_Int32) aLineDash.Dashes);
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("dashLen"), "%" SAL_PRIdINT32, (sal_Int32) aLineDash.DashLen);
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("distance"), "%" SAL_PRIdINT32, (sal_Int32) aLineDash.Distance);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("dots"), "%" SAL_PRIdINT32, (sal_Int32) rLineDash.Dots);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("dotLen"), "%" SAL_PRIdINT32, (sal_Int32) rLineDash.DotLen);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("dashes"), "%" SAL_PRIdINT32, (sal_Int32) rLineDash.Dashes);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("dashLen"), "%" SAL_PRIdINT32, (sal_Int32) rLineDash.DashLen);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("distance"), "%" SAL_PRIdINT32, (sal_Int32) rLineDash.Distance);
     xmlTextWriterEndElement( xmlWriter );
 }
 
@@ -538,22 +538,22 @@ void dumpLineEndNameAsAttribute(const OUString& sLineEndName, xmlTextWriterPtr x
     OUStringToOString(sLineEndName, RTL_TEXTENCODING_UTF8).getStr());
 }
 
-void dumpPolyPolygonBezierCoords(drawing::PolyPolygonBezierCoords aPolyPolygonBezierCoords, xmlTextWriterPtr xmlWriter)
+void dumpPolyPolygonBezierCoords(const drawing::PolyPolygonBezierCoords& rPolyPolygonBezierCoords, xmlTextWriterPtr xmlWriter)
 {
-    dumpPointSequenceSequence(aPolyPolygonBezierCoords.Coordinates, &aPolyPolygonBezierCoords.Flags, xmlWriter);
+    dumpPointSequenceSequence(rPolyPolygonBezierCoords.Coordinates, &rPolyPolygonBezierCoords.Flags, xmlWriter);
 }
 
-void dumpLineStartAsElement(drawing::PolyPolygonBezierCoords aLineStart, xmlTextWriterPtr xmlWriter)
+void dumpLineStartAsElement(const drawing::PolyPolygonBezierCoords& rLineStart, xmlTextWriterPtr xmlWriter)
 {
     xmlTextWriterStartElement(xmlWriter, BAD_CAST( "LineStart" ));
-    dumpPolyPolygonBezierCoords(aLineStart, xmlWriter);
+    dumpPolyPolygonBezierCoords(rLineStart, xmlWriter);
     xmlTextWriterEndElement( xmlWriter );
 }
 
-void dumpLineEndAsElement(drawing::PolyPolygonBezierCoords aLineEnd, xmlTextWriterPtr xmlWriter)
+void dumpLineEndAsElement(const drawing::PolyPolygonBezierCoords& rLineEnd, xmlTextWriterPtr xmlWriter)
 {
     xmlTextWriterStartElement(xmlWriter, BAD_CAST( "LineEnd" ));
-    dumpPolyPolygonBezierCoords(aLineEnd, xmlWriter);
+    dumpPolyPolygonBezierCoords(rLineEnd, xmlWriter);
     xmlTextWriterEndElement( xmlWriter );
 }
 
@@ -623,7 +623,7 @@ void dumpPolygonKindAsAttribute(drawing::PolygonKind ePolygonKind, xmlTextWriter
     }
 }
 
-void dumpPointSequenceSequence(const drawing::PointSequenceSequence& aPointSequenceSequence, uno::Sequence<uno::Sequence< drawing::PolygonFlags > >* pFlags, xmlTextWriterPtr xmlWriter)
+void dumpPointSequenceSequence(const drawing::PointSequenceSequence& aPointSequenceSequence, const uno::Sequence<uno::Sequence< drawing::PolygonFlags > >* pFlags, xmlTextWriterPtr xmlWriter)
 {
     // LibreOffice proudly presents - The Sequenception
     uno::Sequence<uno::Sequence< awt::Point > > pointSequenceSequence = aPointSequenceSequence;
@@ -673,10 +673,10 @@ void dumpPointSequenceSequence(const drawing::PointSequenceSequence& aPointSeque
     }
 }
 
-void dumpPolyPolygonAsElement(const drawing::PointSequenceSequence& aPolyPolygon, xmlTextWriterPtr xmlWriter)
+void dumpPolyPolygonAsElement(const drawing::PointSequenceSequence& rPolyPolygon, xmlTextWriterPtr xmlWriter)
 {
     xmlTextWriterStartElement(xmlWriter, BAD_CAST( "PolyPolygon" ));
-    dumpPointSequenceSequence(aPolyPolygon, NULL, xmlWriter);
+    dumpPointSequenceSequence(rPolyPolygon, NULL, xmlWriter);
     xmlTextWriterEndElement( xmlWriter );
 }
 
@@ -1024,25 +1024,25 @@ void dumpSizeProtectAsAttribute(bool bSizeProtect, xmlTextWriterPtr xmlWriter)
         xmlTextWriterWriteFormatAttribute( xmlWriter, BAD_CAST("sizeProtect"), "%s", "false");
 }
 
-void dumpHomogenMatrixLine3(drawing::HomogenMatrixLine3 aHomogenMatrixLine3, xmlTextWriterPtr xmlWriter)
+void dumpHomogenMatrixLine3(const drawing::HomogenMatrixLine3& rHomogenMatrixLine3, xmlTextWriterPtr xmlWriter)
 {
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("column1"), "%f", aHomogenMatrixLine3.Column1);
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("column2"), "%f", aHomogenMatrixLine3.Column2);
-    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("column3"), "%f", aHomogenMatrixLine3.Column3);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("column1"), "%f", rHomogenMatrixLine3.Column1);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("column2"), "%f", rHomogenMatrixLine3.Column2);
+    xmlTextWriterWriteFormatAttribute(xmlWriter, BAD_CAST("column3"), "%f", rHomogenMatrixLine3.Column3);
 }
 
-void dumpTransformationAsElement(drawing::HomogenMatrix3 const & aTransformation, xmlTextWriterPtr xmlWriter)
+void dumpTransformationAsElement(const drawing::HomogenMatrix3& rTransformation, xmlTextWriterPtr xmlWriter)
 {
     xmlTextWriterStartElement(xmlWriter, BAD_CAST( "Transformation" ));
     {
     xmlTextWriterStartElement(xmlWriter, BAD_CAST( "Line1" ));
-    dumpHomogenMatrixLine3(aTransformation.Line1, xmlWriter);
+    dumpHomogenMatrixLine3(rTransformation.Line1, xmlWriter);
     xmlTextWriterEndElement( xmlWriter );
     xmlTextWriterStartElement(xmlWriter, BAD_CAST( "Line2" ));
-    dumpHomogenMatrixLine3(aTransformation.Line2, xmlWriter);
+    dumpHomogenMatrixLine3(rTransformation.Line2, xmlWriter);
     xmlTextWriterEndElement( xmlWriter );
     xmlTextWriterStartElement(xmlWriter, BAD_CAST( "Line3" ));
-    dumpHomogenMatrixLine3(aTransformation.Line3, xmlWriter);
+    dumpHomogenMatrixLine3(rTransformation.Line3, xmlWriter);
     xmlTextWriterEndElement( xmlWriter );
     }
     xmlTextWriterEndElement( xmlWriter );
diff --git a/drawinglayer/source/primitive2d/metafileprimitive2d.cxx b/drawinglayer/source/primitive2d/metafileprimitive2d.cxx
index 1c8365e..fa19d1d 100644
--- a/drawinglayer/source/primitive2d/metafileprimitive2d.cxx
+++ b/drawinglayer/source/primitive2d/metafileprimitive2d.cxx
@@ -597,7 +597,7 @@ namespace
         const std::vector< basegfx::B2DPoint >& rPositions,
         TargetHolder& rTarget,
         PropertyHolder& rProperties,
-        basegfx::BColor aBColor)
+        const basegfx::BColor& rBColor)
     {
         if(!rPositions.empty())
         {
@@ -606,7 +606,7 @@ namespace
                 rTarget.append(
                     new drawinglayer::primitive2d::PointArrayPrimitive2D(
                         rPositions,
-                        aBColor));
+                        rBColor));
             }
             else
             {
@@ -620,7 +620,7 @@ namespace
                 rTarget.append(
                     new drawinglayer::primitive2d::PointArrayPrimitive2D(
                         aPositions,
-                        aBColor));
+                        rBColor));
             }
         }
     }
diff --git a/editeng/source/editeng/impedit.hxx b/editeng/source/editeng/impedit.hxx
index bacff39..ae2376b 100644
--- a/editeng/source/editeng/impedit.hxx
+++ b/editeng/source/editeng/impedit.hxx
@@ -530,7 +530,7 @@ private:
     void                ParaAttribsToCharAttribs( ContentNode* pNode );
     void                GetCharAttribs( sal_Int32 nPara, std::vector<EECharAttrib>& rLst ) const;
 
-    EditTextObject*     CreateTextObject( EditSelection aSelection, SfxItemPool*, bool bAllowBigObjects = false, sal_Int32 nBigObjStart = 0 );
+    EditTextObject*     CreateTextObject(EditSelection aSelection, SfxItemPool*, bool bAllowBigObjects = false, sal_Int32 nBigObjStart = 0);
     EditSelection       InsertTextObject( const EditTextObject&, EditPaM aPaM );
     EditSelection       InsertText( ::com::sun::star::uno::Reference< ::com::sun::star::datatransfer::XTransferable >& rxDataObj, const OUString& rBaseURL, const EditPaM& rPaM, bool bUseSpecial );
 
@@ -619,9 +619,9 @@ private:
     EditPaM             ReadBin( SvStream& rInput, EditSelection aSel );
     sal_uInt32          WriteText( SvStream& rOutput, EditSelection aSel );
     sal_uInt32          WriteRTF( SvStream& rOutput, EditSelection aSel );
-    sal_uInt32          WriteXML( SvStream& rOutput, EditSelection aSel );
+    sal_uInt32          WriteXML(SvStream& rOutput, const EditSelection& rSel);
     sal_uInt32          WriteHTML( SvStream& rOutput, EditSelection aSel );
-    sal_uInt32 WriteBin( SvStream& rOutput, EditSelection aSel, bool bStoreUnicode = false );
+    sal_uInt32          WriteBin(SvStream& rOutput, const EditSelection& rSel, bool bStoreUnicode = false);
 
     void                WriteItemAsRTF( const SfxPoolItem& rItem, SvStream& rOutput, sal_Int32 nPara, sal_Int32 nPos,
                         std::vector<SvxFontItem*>& rFontTable, SvxColorList& rColorList );
@@ -775,11 +775,11 @@ public:
     EditPaM         InsertField(const EditSelection& rCurSel, const SvxFieldItem& rFld);
     bool        UpdateFields();
 
-    EditPaM         Read( SvStream& rInput, const OUString& rBaseURL, EETextFormat eFormat, EditSelection aSel, SvKeyValueIterator* pHTTPHeaderAttrs = NULL );
-    void            Write( SvStream& rOutput, EETextFormat eFormat, EditSelection aSel );
+    EditPaM         Read(SvStream& rInput, const OUString& rBaseURL, EETextFormat eFormat, const EditSelection& rSel, SvKeyValueIterator* pHTTPHeaderAttrs = NULL);
+    void            Write(SvStream& rOutput, EETextFormat eFormat, const EditSelection& rSel);
 
     EditTextObject* CreateTextObject();
-    EditTextObject* CreateTextObject( EditSelection aSel );
+    EditTextObject* CreateTextObject(const EditSelection& rSel);
     void            SetText( const EditTextObject& rTextObject );
     EditSelection   InsertText( const EditTextObject& rTextObject, EditSelection aSel );
 
diff --git a/editeng/source/editeng/impedit4.cxx b/editeng/source/editeng/impedit4.cxx
index f843a63..de54276 100644
--- a/editeng/source/editeng/impedit4.cxx
+++ b/editeng/source/editeng/impedit4.cxx
@@ -86,21 +86,21 @@ using namespace ::com::sun::star::beans;
 using namespace ::com::sun::star::linguistic2;
 
 
-EditPaM ImpEditEngine::Read( SvStream& rInput, const OUString& rBaseURL, EETextFormat eFormat, EditSelection aSel, SvKeyValueIterator* pHTTPHeaderAttrs )
+EditPaM ImpEditEngine::Read(SvStream& rInput, const OUString& rBaseURL, EETextFormat eFormat, const EditSelection& rSel, SvKeyValueIterator* pHTTPHeaderAttrs)
 {
     bool _bUpdate = GetUpdateMode();
     SetUpdateMode( false );
     EditPaM aPaM;
     if ( eFormat == EE_FORMAT_TEXT )
-        aPaM = ReadText( rInput, aSel );
+        aPaM = ReadText( rInput, rSel );
     else if ( eFormat == EE_FORMAT_RTF )
-        aPaM = ReadRTF( rInput, aSel );
+        aPaM = ReadRTF( rInput, rSel );
     else if ( eFormat == EE_FORMAT_XML )
-        aPaM = ReadXML( rInput, aSel );
+        aPaM = ReadXML( rInput, rSel );
     else if ( eFormat == EE_FORMAT_HTML )
-        aPaM = ReadHTML( rInput, rBaseURL, aSel, pHTTPHeaderAttrs );
+        aPaM = ReadHTML( rInput, rBaseURL, rSel, pHTTPHeaderAttrs );
     else if ( eFormat == EE_FORMAT_BIN)
-        aPaM = ReadBin( rInput, aSel );
+        aPaM = ReadBin( rInput, rSel );
     else
     {
         OSL_FAIL( "Read: Unknown Format" );
@@ -199,7 +199,7 @@ EditPaM ImpEditEngine::ReadBin( SvStream& rInput, EditSelection aSel )
     return aLastPaM;
 }
 
-void ImpEditEngine::Write( SvStream& rOutput, EETextFormat eFormat, EditSelection aSel )
+void ImpEditEngine::Write(SvStream& rOutput, EETextFormat eFormat, const EditSelection& rSel)
 {
     if ( !rOutput.IsWritable() )
         rOutput.SetError( SVSTREAM_WRITE_ERROR );
@@ -207,15 +207,15 @@ void ImpEditEngine::Write( SvStream& rOutput, EETextFormat eFormat, EditSelectio
     if ( !rOutput.GetError() )
     {
         if ( eFormat == EE_FORMAT_TEXT )
-            WriteText( rOutput, aSel );
+            WriteText( rOutput, rSel );
         else if ( eFormat == EE_FORMAT_RTF )
-            WriteRTF( rOutput, aSel );
+            WriteRTF( rOutput, rSel );
         else if ( eFormat == EE_FORMAT_XML )
-            WriteXML( rOutput, aSel );
+            WriteXML( rOutput, rSel );
         else if ( eFormat == EE_FORMAT_HTML )
-            WriteHTML( rOutput, aSel );
+            WriteHTML( rOutput, rSel );
         else if ( eFormat == EE_FORMAT_BIN)
-            WriteBin( rOutput, aSel );
+            WriteBin( rOutput, rSel );
         else
         {
             OSL_FAIL( "Write: Unknown Format" );
@@ -290,17 +290,17 @@ static void lcl_FindValidAttribs( ItemList& rLst, ContentNode* pNode, sal_Int32
     }
 }
 
-sal_uInt32 ImpEditEngine::WriteBin( SvStream& rOutput, EditSelection aSel, bool bStoreUnicodeStrings )
+sal_uInt32 ImpEditEngine::WriteBin(SvStream& rOutput, const EditSelection& rSel, bool bStoreUnicodeStrings)
 {
-    std::unique_ptr<EditTextObject> xObj(CreateTextObject(aSel, NULL));
+    std::unique_ptr<EditTextObject> xObj(CreateTextObject(rSel, NULL));
     xObj->mpImpl->StoreUnicodeStrings(bStoreUnicodeStrings);
     xObj->Store(rOutput);
     return 0;
 }
 
-sal_uInt32 ImpEditEngine::WriteXML( SvStream& rOutput, EditSelection aSel )
+sal_uInt32 ImpEditEngine::WriteXML(SvStream& rOutput, const EditSelection& rSel)
 {
-    ESelection aESel = CreateESel( aSel );
+    ESelection aESel = CreateESel(rSel);
 
     SvxWriteXML( *GetEditEnginePtr(), rOutput, aESel );
 
@@ -1013,9 +1013,9 @@ EditTextObject* ImpEditEngine::CreateTextObject()
     return CreateTextObject( aCompleteSelection );
 }
 
-EditTextObject* ImpEditEngine::CreateTextObject( EditSelection aSel )
+EditTextObject* ImpEditEngine::CreateTextObject(const EditSelection& rSel)
 {
-    return CreateTextObject( aSel, GetEditTextObjectPool(), aStatus.AllowBigObjects(), nBigTextObjectStart );
+    return CreateTextObject(rSel, GetEditTextObjectPool(), aStatus.AllowBigObjects(), nBigTextObjectStart);
 }
 
 EditTextObject* ImpEditEngine::CreateTextObject( EditSelection aSel, SfxItemPool* pPool, bool bAllowBigObjects, sal_Int32 nBigObjectStart )
diff --git a/filter/source/graphicfilter/eos2met/eos2met.cxx b/filter/source/graphicfilter/eos2met/eos2met.cxx
index 0d21b0a..780ac5d 100644
--- a/filter/source/graphicfilter/eos2met/eos2met.cxx
+++ b/filter/source/graphicfilter/eos2met/eos2met.cxx
@@ -211,7 +211,7 @@ private:
     void METLine(const tools::PolyPolygon & rPolyPolygon);
     void METLineAtCurPos(Point aPt);
     void METBox(bool bFill, bool bBoundary,
-                Rectangle aRect, sal_uInt32 nHAxis, sal_uInt32 nVAxis);
+                const Rectangle& rRect, sal_uInt32 nHAxis, sal_uInt32 nVAxis);
     void METFullArc(Point aCenter, double fMultiplier);
     void METPartialArcAtCurPos(Point aCenter, double fMultiplier,
                                double fStartAngle, double fSweepAngle);
@@ -1319,7 +1319,6 @@ void METWriter::METLine(const tools::PolyPolygon & rPolyPolygon)
     }
 }
 
-
 void METWriter::METLineAtCurPos(Point aPt)
 {
     WillWriteOrder(10);
@@ -1327,9 +1326,8 @@ void METWriter::METLineAtCurPos(Point aPt)
     WritePoint(aPt);
 }
 
-
 void METWriter::METBox(bool bFill, bool bBoundary,
-                       Rectangle aRect, sal_uInt32 nHAxis, sal_uInt32 nVAxis)
+                       const Rectangle& rRect, sal_uInt32 nHAxis, sal_uInt32 nVAxis)
 {
     sal_uInt8 nFlags=0;
     if (bFill)     nFlags|=0x40;
@@ -1337,12 +1335,11 @@ void METWriter::METBox(bool bFill, bool bBoundary,
 
     WillWriteOrder(28);
     pMET->WriteUChar( 0xc0 ).WriteUChar( 26 ).WriteUChar( nFlags ).WriteUChar( 0 );
-    WritePoint(aRect.BottomLeft());
-    WritePoint(aRect.TopRight());
+    WritePoint(rRect.BottomLeft());
+    WritePoint(rRect.TopRight());
     pMET->WriteUInt32( nHAxis ).WriteUInt32( nVAxis );
 }
 
-
 void METWriter::METFullArc(Point aCenter, double fMultiplier)
 {
     WillWriteOrder(14);
@@ -1351,7 +1348,6 @@ void METWriter::METFullArc(Point aCenter, double fMultiplier)
     pMET->WriteInt32( fMultiplier*65536.0+0.5 );
 }
 
-
 void METWriter::METPartialArcAtCurPos(Point aCenter, double fMultiplier,
                                       double fStartAngle, double fSweepAngle)
 {
diff --git a/framework/inc/services/layoutmanager.hxx b/framework/inc/services/layoutmanager.hxx
index b0b2a75..ae1f300 100644
--- a/framework/inc/services/layoutmanager.hxx
+++ b/framework/inc/services/layoutmanager.hxx
@@ -253,7 +253,7 @@ namespace framework
             void    implts_setVisibleState( bool bShow );
             void    implts_updateUIElementsVisibleState( bool bShow );
             void    implts_setCurrentUIVisibility( bool bShow );
-            void    implts_notifyListeners( short nEvent, ::com::sun::star::uno::Any aInfoParam );
+            void    implts_notifyListeners(short nEvent, const css::uno::Any& rInfoParam);
 
             DECL_LINK( OptionsChanged, void* );
             DECL_LINK( SettingsChanged, void* );
diff --git a/framework/source/layoutmanager/layoutmanager.cxx b/framework/source/layoutmanager/layoutmanager.cxx
index d1d5dbc..d4e4eee 100644
--- a/framework/source/layoutmanager/layoutmanager.cxx
+++ b/framework/source/layoutmanager/layoutmanager.cxx
@@ -2628,7 +2628,7 @@ throw (uno::RuntimeException, std::exception)
     m_aListenerContainer.removeInterface( cppu::UnoType<frame::XLayoutManagerListener>::get(), xListener );
 }
 
-void LayoutManager::implts_notifyListeners( short nEvent, uno::Any aInfoParam )
+void LayoutManager::implts_notifyListeners(short nEvent, const uno::Any& rInfoParam)
 {
     lang::EventObject                  aSource( static_cast< ::cppu::OWeakObject*>(this) );
     ::cppu::OInterfaceContainerHelper* pContainer = m_aListenerContainer.getContainer( cppu::UnoType<frame::XLayoutManagerListener>::get());
@@ -2639,7 +2639,7 @@ void LayoutManager::implts_notifyListeners( short nEvent, uno::Any aInfoParam )
         {
             try
             {
-                static_cast<frame::XLayoutManagerListener*>(pIterator.next())->layoutEvent( aSource, nEvent, aInfoParam );
+                static_cast<frame::XLayoutManagerListener*>(pIterator.next())->layoutEvent(aSource, nEvent, rInfoParam);
             }
             catch( const uno::RuntimeException& )
             {
diff --git a/include/basegfx/matrix/b3dhommatrix.hxx b/include/basegfx/matrix/b3dhommatrix.hxx
index ad7c47d..0ffd911 100644
--- a/include/basegfx/matrix/b3dhommatrix.hxx
+++ b/include/basegfx/matrix/b3dhommatrix.hxx
@@ -86,7 +86,7 @@ namespace basegfx
 
         // build orientation matrix
         void orientation(
-            B3DPoint aVRP = B3DPoint(0.0,0.0,1.0),
+            const B3DPoint& rVRP = B3DPoint(0.0,0.0,1.0),
             B3DVector aVPN = B3DVector(0.0,0.0,1.0),
             B3DVector aVUV = B3DVector(0.0,1.0,0.0));
 
diff --git a/include/registry/reflwrit.hxx b/include/registry/reflwrit.hxx
index f97574d..75bff94 100644
--- a/include/registry/reflwrit.hxx
+++ b/include/registry/reflwrit.hxx
@@ -143,13 +143,13 @@ public:
         @param constValue specifies the value of the field. The value is only interesting
                           for enum values or constants.
      */
-    inline void setFieldData( sal_uInt16                index,
+    inline void setFieldData( sal_uInt16              index,
                               const rtl::OUString&    name,
                               const rtl::OUString&    typeName,
                               const rtl::OUString&    doku,
                               const rtl::OUString&    fileName,
-                              RTFieldAccess             access,
-                              RTConstValue              constValue = RTConstValue());
+                              RTFieldAccess           access,
+                              const RTConstValue&     constValue = RTConstValue());
 
     /** sets the data for a method.
 
@@ -270,13 +270,13 @@ inline RegistryTypeWriter& RegistryTypeWriter::operator == (const RegistryTypeWr
     return *this;
 }
 
-inline void RegistryTypeWriter::setFieldData( sal_uInt16                index,
+inline void RegistryTypeWriter::setFieldData( sal_uInt16              index,
                                               const rtl::OUString&    name,
                                               const rtl::OUString&    typeName,
                                               const rtl::OUString&    doku,
                                               const rtl::OUString&    fileName,
-                                              RTFieldAccess             access,
-                                              RTConstValue              constValue)
+                                              RTFieldAccess           access,
+                                              const RTConstValue&     constValue)
 {
     m_pApi->setFieldData(m_hImpl, index, name.pData, typeName.pData, doku.pData, fileName.pData, access, constValue.m_type, constValue.m_value);
 }
diff --git a/include/sfx2/dinfdlg.hxx b/include/sfx2/dinfdlg.hxx
index 027f6bc..79ba1c0 100644
--- a/include/sfx2/dinfdlg.hxx
+++ b/include/sfx2/dinfdlg.hxx
@@ -118,7 +118,7 @@ public:
 
     ::com::sun::star::util::DateTime
                 getCreationDate() const { return m_CreationDate; }
-    void        setCreationDate(::com::sun::star::util::DateTime i_val) {
+    void        setCreationDate(const css::util::DateTime& i_val) {
                     m_CreationDate = i_val;
                 }
     OUString getModifiedBy() const { return m_ModifiedBy; }
@@ -126,14 +126,14 @@ public:
 
     ::com::sun::star::util::DateTime
                 getModificationDate() const { return m_ModificationDate; }
-    void        setModificationDate(::com::sun::star::util::DateTime i_val) {
+    void        setModificationDate(const css::util::DateTime& i_val) {
                     m_ModificationDate = i_val;
                 }
     OUString getPrintedBy() const { return m_PrintedBy; }
     void        setPrintedBy(const OUString& i_val) { m_PrintedBy = i_val; }
     ::com::sun::star::util::DateTime
                 getPrintDate() const { return m_PrintDate; }
-    void        setPrintDate(::com::sun::star::util::DateTime i_val) {
+    void        setPrintDate(const css::util::DateTime& i_val) {
                     m_PrintDate = i_val;
                 }
     sal_Int16   getEditingCycles() const { return m_EditingCycles; }
diff --git a/include/sfx2/docfile.hxx b/include/sfx2/docfile.hxx
index 7087584..26e3460 100644
--- a/include/sfx2/docfile.hxx
+++ b/include/sfx2/docfile.hxx
@@ -265,7 +265,7 @@ public:
     static css::uno::Sequence < css::util::RevisionTag > GetVersionList(
                     const css::uno::Reference< css::embed::XStorage >& xStorage );
     static OUString CreateTempCopyWithExt( const OUString& aURL );
-    static bool CallApproveHandler( const css::uno::Reference< css::task::XInteractionHandler >& xHandler, css::uno::Any aRequest, bool bAllowAbort );
+    static bool CallApproveHandler(const css::uno::Reference< css::task::XInteractionHandler >& xHandler, const css::uno::Any& rRequest, bool bAllowAbort);
 
     static bool         SetWritableForUserOnly( const OUString& aURL );
     static sal_uInt32   CreatePasswordToModifyHash( const OUString& aPasswd, bool bWriter );
diff --git a/include/svtools/ctrlbox.hxx b/include/svtools/ctrlbox.hxx
index 6f78ee3..d382a9d 100644
--- a/include/svtools/ctrlbox.hxx
+++ b/include/svtools/ctrlbox.hxx
@@ -311,11 +311,11 @@ public:
 
     using ListBox::InsertEntry;
     /** Insert a listbox entry with all widths in Twips. */
-    void            InsertEntry( BorderWidthImpl aWidthImpl,
+    void            InsertEntry(const BorderWidthImpl& rWidthImpl,
                         sal_uInt16 nStyle, long nMinWidth = 0,
                         ColorFunc pColor1Fn = &sameColor,
                         ColorFunc pColor2Fn = &sameColor,
-                        ColorDistFunc pColorDistFn = &sameDistColor );
+                        ColorDistFunc pColorDistFn = &sameDistColor);
 
     using ListBox::GetEntryPos;
     sal_Int32  GetEntryPos( sal_uInt16 nStyle = com::sun::star::table::BorderLineStyle::SOLID ) const;
diff --git a/include/toolkit/helper/vclunohelper.hxx b/include/toolkit/helper/vclunohelper.hxx
index e8a6c9b..dc1ae88 100644
--- a/include/toolkit/helper/vclunohelper.hxx
+++ b/include/toolkit/helper/vclunohelper.hxx
@@ -110,7 +110,7 @@ public:
     static FontItalic                               ConvertFontSlant( css::awt::FontSlant );
 
     // Rectangle
-    static bool                                 IsZero( ::com::sun::star::awt::Rectangle rRect );
+    static bool                                     IsZero(const css::awt::Rectangle& rRect);
 
     static ::com::sun::star::uno::Reference< ::com::sun::star::awt::XControlContainer>  CreateControlContainer( vcl::Window* pWindow );
 
diff --git a/include/tools/b3dtrans.hxx b/include/tools/b3dtrans.hxx
index 7787da5..ba3e87b 100644
--- a/include/tools/b3dtrans.hxx
+++ b/include/tools/b3dtrans.hxx
@@ -124,9 +124,9 @@ public:
 
     // Orientation
     void SetOrientation(
-        basegfx::B3DPoint aVRP = basegfx::B3DPoint(0.0,0.0,1.0),
-        basegfx::B3DVector aVPN = basegfx::B3DVector(0.0,0.0,1.0),
-        basegfx::B3DVector aVUP = basegfx::B3DVector(0.0,1.0,0.0));
+        const basegfx::B3DPoint& rVRP = basegfx::B3DPoint(0.0,0.0,1.0),
+        const basegfx::B3DVector& rVPN = basegfx::B3DVector(0.0,0.0,1.0),
+        const basegfx::B3DVector& rVUP = basegfx::B3DVector(0.0,1.0,0.0));
     const basegfx::B3DHomMatrix& GetOrientation() { return maOrientation; }
     const basegfx::B3DHomMatrix& GetInvOrientation() { return maInvOrientation; }
 
diff --git a/include/tools/simplerm.hxx b/include/tools/simplerm.hxx
index 2674386..09fd732 100644
--- a/include/tools/simplerm.hxx
+++ b/include/tools/simplerm.hxx
@@ -51,7 +51,7 @@ public:
     virtual                 ~SimpleResMgr();
 
     static SimpleResMgr*    Create( const sal_Char* pPrefixName,
-                                    LanguageTag aLocale = LanguageTag( LANGUAGE_SYSTEM) );// only in VCL
+                                    const LanguageTag& rLocale = LanguageTag( LANGUAGE_SYSTEM) );// only in VCL
 
     bool                    IsValid() const { return m_pResImpl != NULL; }
 
diff --git a/include/vcl/longcurr.hxx b/include/vcl/longcurr.hxx
index 74de049..0c2d1a9 100644
--- a/include/vcl/longcurr.hxx
+++ b/include/vcl/longcurr.hxx
@@ -60,14 +60,14 @@ public:
     void                    SetCurrencySymbol( const OUString& rStr );
     OUString                GetCurrencySymbol() const;
 
-    void                    SetMin( BigInt nNewMin );
+    void                    SetMin(const BigInt& rNewMin);
     BigInt                  GetMin() const { return mnMin; }
-    void                    SetMax( BigInt nNewMax );
+    void                    SetMax(const BigInt& rNewMax);
     BigInt                  GetMax() const { return mnMax; }
 
     void                    SetDecimalDigits( sal_uInt16 nDigits );
     sal_uInt16                  GetDecimalDigits() const { return mnDecimalDigits;}
-    void                    SetValue( BigInt nNewValue );
+    void                    SetValue(const BigInt& rNewValue);
     void                    SetUserValue( BigInt nNewValue );
     BigInt                  GetValue() const;
     bool                IsEmptyValue() const { return GetField()->GetText().isEmpty(); }
@@ -81,7 +81,7 @@ public:
 
 class VCL_DLLPUBLIC LongCurrencyField : public SpinField, public LongCurrencyFormatter
 {
-    friend void ImplNewLongCurrencyFieldValue( LongCurrencyField*, BigInt );
+    friend void ImplNewLongCurrencyFieldValue(LongCurrencyField*, const BigInt&);
 
 private:
     BigInt          mnSpinSize;
@@ -101,11 +101,11 @@ public:
     void            First() SAL_OVERRIDE;
     void            Last() SAL_OVERRIDE;
 
-    void            SetFirst( BigInt nNewFirst ) { mnFirst = nNewFirst; }
+    void            SetFirst(const BigInt& rNewFirst ) { mnFirst = rNewFirst; }
     BigInt          GetFirst() const { return mnFirst; }
-    void            SetLast( BigInt nNewLast ) { mnLast = nNewLast; }
+    void            SetLast(const BigInt& rNewLast ) { mnLast = rNewLast; }
     BigInt          GetLast() const { return mnLast; }
-    void            SetSpinSize( BigInt nNewSize ) { mnSpinSize = nNewSize; }
+    void            SetSpinSize(const BigInt& rNewSize) { mnSpinSize = rNewSize; }
     BigInt          GetSpinSize() const { return mnSpinSize; }
 };
 
diff --git a/include/vcl/taskpanelist.hxx b/include/vcl/taskpanelist.hxx
index 6e8888d..c8a6abd 100644
--- a/include/vcl/taskpanelist.hxx
+++ b/include/vcl/taskpanelist.hxx
@@ -40,7 +40,7 @@ public:
 
     void AddWindow( vcl::Window *pWindow );
     void RemoveWindow( vcl::Window *pWindow );
-    bool HandleKeyEvent( KeyEvent aKeyEvent );
+    bool HandleKeyEvent(const KeyEvent& rKeyEvent);
 };
 
 #endif
diff --git a/include/vcl/toolbox.hxx b/include/vcl/toolbox.hxx
index 672b229..44b4b8c 100644
--- a/include/vcl/toolbox.hxx
+++ b/include/vcl/toolbox.hxx
@@ -206,7 +206,7 @@ private:
     SAL_DLLPRIVATE sal_uInt16          ImplCalcBreaks( long nWidth, long* pMaxLineWidth, bool bCalcHorz );
     SAL_DLLPRIVATE void            ImplFormat( bool bResize = false );
     SAL_DLLPRIVATE void            ImplDrawSpin( bool bUpperIn, bool bLowerIn );
-    SAL_DLLPRIVATE void            ImplDrawSeparator( sal_uInt16 nPos, Rectangle rRect );
+    SAL_DLLPRIVATE void            ImplDrawSeparator(sal_uInt16 nPos, const Rectangle& rRect);
     SAL_DLLPRIVATE void            ImplDrawItem( sal_uInt16 nPos, sal_uInt16 nHighlight = 0, bool bPaint = false, bool bLayout = false );
     using Window::ImplInvalidate;
     SAL_DLLPRIVATE void            ImplInvalidate( bool bNewCalc = false, bool bFullPaint = false );
diff --git a/lingucomponent/source/languageguessing/guess.cxx b/lingucomponent/source/languageguessing/guess.cxx
index 833d603..33fe2c3 100644
--- a/lingucomponent/source/languageguessing/guess.cxx
+++ b/lingucomponent/source/languageguessing/guess.cxx
@@ -109,10 +109,7 @@ Guess::~Guess()
 {
 }
 
-
-
-
-bool Guess::operator==(string lang)
+bool Guess::operator==(const string& lang)
 {
     string toString;
     toString += GetLanguage();
diff --git a/lingucomponent/source/languageguessing/guess.hxx b/lingucomponent/source/languageguessing/guess.hxx
index 65febf5..4e9644f 100644
--- a/lingucomponent/source/languageguessing/guess.hxx
+++ b/lingucomponent/source/languageguessing/guess.hxx
@@ -52,7 +52,7 @@ class Guess{
         string GetCountry() { return country_str;}
         string GetEncoding() { return encoding_str;}
 
-        bool operator==(string lang);
+        bool operator==(const string& lang);
 
     protected:
         string language_str;
diff --git a/lingucomponent/source/languageguessing/simpleguesser.cxx b/lingucomponent/source/languageguessing/simpleguesser.cxx
index 055e785..3c33b98 100644
--- a/lingucomponent/source/languageguessing/simpleguesser.cxx
+++ b/lingucomponent/source/languageguessing/simpleguesser.cxx
@@ -193,7 +193,7 @@ vector<Guess> SimpleGuesser::GetAllManagedLanguages()
     return GetManagedLanguages( sal::static_int_cast< char >( 0xFF ));
 }
 
-void SimpleGuesser::XableLanguage(string lang, char mask)
+void SimpleGuesser::XableLanguage(const string& lang, char mask)
 {
     textcat_t *tables = (textcat_t*)h;
 
@@ -207,12 +207,12 @@ void SimpleGuesser::XableLanguage(string lang, char mask)
     }
 }
 
-void SimpleGuesser::EnableLanguage(string lang)
+void SimpleGuesser::EnableLanguage(const string& lang)
 {
     XableLanguage(lang,  sal::static_int_cast< char >( 0xF0 ));
 }
 
-void SimpleGuesser::DisableLanguage(string lang)
+void SimpleGuesser::DisableLanguage(const string& lang)
 {
     XableLanguage(lang,  sal::static_int_cast< char >( 0x0F ));
 }
diff --git a/lingucomponent/source/languageguessing/simpleguesser.hxx b/lingucomponent/source/languageguessing/simpleguesser.hxx
index 102ff8f..db6cc6a 100644
--- a/lingucomponent/source/languageguessing/simpleguesser.hxx
+++ b/lingucomponent/source/languageguessing/simpleguesser.hxx
@@ -83,13 +83,13 @@ public:
      * Mark a language enabled
      * @param string lang the language to enable (build like language-COUNTRY-encoding)
      */
-    void EnableLanguage(string lang);
+    void EnableLanguage(const string& lang);
 
     /**
      * Mark a language disabled
      * @param string lang the language to disable (build like language-COUNTRY-encoding)
      */
-    void DisableLanguage(string lang);
+    void DisableLanguage(const string& lang);
 
     /**
      * Load a new DB of fingerprints
@@ -107,7 +107,7 @@ protected:
     vector<Guess> GetManagedLanguages(const char mask);
 
     //Like getManagedLanguages, this function enable or disable a language and it depends of the mask
-    void XableLanguage(string lang, char mask);
+    void XableLanguage(const string& lang, char mask);
 };
 
 #endif
diff --git a/reportdesign/source/ui/dlg/CondFormat.cxx b/reportdesign/source/ui/dlg/CondFormat.cxx
index 07b06dd..16aa8a3 100644
--- a/reportdesign/source/ui/dlg/CondFormat.cxx
+++ b/reportdesign/source/ui/dlg/CondFormat.cxx
@@ -358,7 +358,7 @@ namespace rptui
         impl_conditionCountChanged();
     }
 
-    void ConditionalFormattingDialog::applyCommand( size_t _nCondIndex, sal_uInt16 _nCommandId, const ::Color _aColor )
+    void ConditionalFormattingDialog::applyCommand(size_t _nCondIndex, sal_uInt16 _nCommandId, const ::Color& rColor)
     {
         OSL_PRECOND( _nCommandId, "ConditionalFormattingDialog::applyCommand: illegal command id!" );
         try
@@ -374,7 +374,7 @@ namespace rptui
             aArgs[1].Value <<= VCLUnoHelper::GetInterface(this);
 
             aArgs[2].Name = PROPERTY_FONTCOLOR;
-            aArgs[2].Value <<= (sal_uInt32)_aColor.GetColor();
+            aArgs[2].Value <<= (sal_uInt32)rColor.GetColor();
 
             // we use this way to create undo actions
             m_rController.executeUnChecked(_nCommandId,aArgs);
diff --git a/reportdesign/source/ui/inc/CondFormat.hxx b/reportdesign/source/ui/inc/CondFormat.hxx
index 254edf9..19c3cc2 100644
--- a/reportdesign/source/ui/inc/CondFormat.hxx
+++ b/reportdesign/source/ui/inc/CondFormat.hxx
@@ -53,7 +53,7 @@ namespace rptui
     public:
         virtual void            addCondition( size_t _nAddAfterIndex ) = 0;
         virtual void            deleteCondition( size_t _nCondIndex ) = 0;
-        virtual void            applyCommand( size_t _nCondIndex, sal_uInt16 _nCommandId, const ::Color _aColor ) = 0;
+        virtual void            applyCommand( size_t _nCondIndex, sal_uInt16 _nCommandId, const ::Color& rColor ) = 0;
         virtual void            moveConditionUp( size_t _nCondIndex ) = 0;
         virtual void            moveConditionDown( size_t _nCondIndex ) = 0;
         virtual OUString getDataField() const = 0;
@@ -102,7 +102,7 @@ namespace rptui
         // IConditionalFormatAction overridables
         virtual void addCondition( size_t _nAddAfterIndex ) SAL_OVERRIDE;
         virtual void deleteCondition( size_t _nCondIndex ) SAL_OVERRIDE;
-        virtual void applyCommand( size_t _nCondIndex, sal_uInt16 _nCommandId, const ::Color _aColor ) SAL_OVERRIDE;
+        virtual void applyCommand( size_t _nCondIndex, sal_uInt16 _nCommandId, const ::Color& rColor ) SAL_OVERRIDE;
         virtual void moveConditionUp( size_t _nCondIndex ) SAL_OVERRIDE;
         virtual void moveConditionDown( size_t _nCondIndex ) SAL_OVERRIDE;
         virtual OUString getDataField() const SAL_OVERRIDE;
diff --git a/sax/qa/cppunit/test_converter.cxx b/sax/qa/cppunit/test_converter.cxx
index 32b65f4..6de224a 100644
--- a/sax/qa/cppunit/test_converter.cxx
+++ b/sax/qa/cppunit/test_converter.cxx
@@ -154,7 +154,7 @@ void ConverterTest::testDuration()
 }
 
 
-static bool eqDateTime(util::DateTime a, util::DateTime b) {
+static bool eqDateTime(const util::DateTime& a, const util::DateTime& b) {
     return a.Year == b.Year && a.Month == b.Month && a.Day == b.Day
         && a.Hours == b.Hours && a.Minutes == b.Minutes
         && a.Seconds == b.Seconds
diff --git a/sfx2/source/doc/docfile.cxx b/sfx2/source/doc/docfile.cxx
index 8422c5e..5d3edd3 100644
--- a/sfx2/source/doc/docfile.cxx
+++ b/sfx2/source/doc/docfile.cxx
@@ -3525,7 +3525,7 @@ OUString SfxMedium::CreateTempCopyWithExt( const OUString& aURL )
     return aResult;
 }
 
-bool SfxMedium::CallApproveHandler( const uno::Reference< task::XInteractionHandler >& xHandler, uno::Any aRequest, bool bAllowAbort )
+bool SfxMedium::CallApproveHandler(const uno::Reference< task::XInteractionHandler >& xHandler, const uno::Any& rRequest, bool bAllowAbort)
 {
     bool bResult = false;
 
@@ -3544,7 +3544,7 @@ bool SfxMedium::CallApproveHandler( const uno::Reference< task::XInteractionHand
                 aContinuations[ 1 ] = pAbort.get();
             }
 
-            xHandler->handle(::framework::InteractionRequest::CreateRequest (aRequest,aContinuations));
+            xHandler->handle(::framework::InteractionRequest::CreateRequest(rRequest, aContinuations));
             bResult = pApprove->wasSelected();
         }
         catch( const Exception& )
diff --git a/shell/inc/internal/metainforeader.hxx b/shell/inc/internal/metainforeader.hxx
index b9f86fd..047bf77 100644
--- a/shell/inc/internal/metainforeader.hxx
+++ b/shell/inc/internal/metainforeader.hxx
@@ -43,7 +43,7 @@ public:
         @param TagName
         the name of the tag that will be retrieved.
     */
-    bool hasTag(std::wstring TagName) const;
+    bool hasTag(const std::wstring& TagName) const;
 
 
     /** Get a specific tag content, compound tags will be returned as comma separated list.
@@ -51,7 +51,7 @@ public:
         @param TagName
         the name of the tag that will be retrieved.
     */
-    std::wstring getTagData( const std::wstring& TagName);
+    std::wstring getTagData(const std::wstring& TagName);
 
     /** check if the a tag has the specific attribute.
 
@@ -60,7 +60,7 @@ public:
         @param AttributeName
         the name of the attribute.
     */
-    bool hasTagAttribute( const std::wstring TagName,  std::wstring AttributeName);
+    bool hasTagAttribute(const std::wstring& TagName,  const std::wstring& AttributeName);
 
     /** Get a specific attribute content.
 
@@ -69,7 +69,7 @@ public:
         @param AttributeName
         the name of the attribute.
     */
-    std::wstring getTagAttribute( const std::wstring TagName,  std::wstring AttributeName);
+    std::wstring getTagAttribute(const std::wstring& TagName,  const std::wstring& AttributeName);
 
     /** Get the default language of the whole document.
     */
diff --git a/shell/inc/internal/thumbviewer.hxx b/shell/inc/internal/thumbviewer.hxx
index b6f9ea4..8a3bbed 100644
--- a/shell/inc/internal/thumbviewer.hxx
+++ b/shell/inc/internal/thumbviewer.hxx
@@ -98,7 +98,7 @@ public:
             /* [out] */ LPOLESTR __RPC_FAR *ppszFileName);
 
 private:
-    Gdiplus::Rect CalcScaledAspectRatio(Gdiplus::Rect src, Gdiplus::Rect dest);
+    Gdiplus::Rect CalcScaledAspectRatio(const Gdiplus::Rect& src, const Gdiplus::Rect& dest);
 
 private:
     long         ref_count_;
diff --git a/shell/source/win32/ooofilereader/autostyletag.cxx b/shell/source/win32/ooofilereader/autostyletag.cxx
index d6c3c14..f2220d9 100644
--- a/shell/source/win32/ooofilereader/autostyletag.cxx
+++ b/shell/source/win32/ooofilereader/autostyletag.cxx
@@ -77,7 +77,7 @@ void CAutoStyleTag::setStyle( ::std::wstring const & Style )
     m_CurrentStyleLocalePair.first = Style;
 }
 
-void CAutoStyleTag::setLocale( LocaleSet_t Locale )
+void CAutoStyleTag::setLocale(const LocaleSet_t& Locale)
 {
     m_CurrentStyleLocalePair.second = Locale;
 }
diff --git a/shell/source/win32/ooofilereader/autostyletag.hxx b/shell/source/win32/ooofilereader/autostyletag.hxx
index 3982b0c..6b2140f 100644
--- a/shell/source/win32/ooofilereader/autostyletag.hxx
+++ b/shell/source/win32/ooofilereader/autostyletag.hxx
@@ -48,7 +48,7 @@ class CAutoStyleTag : public ITag
         virtual ::std::wstring const getTagAttribute( ::std::wstring  const & /*attrname*/ ){ return ::std::wstring() ; };
 
         void setStyle( ::std::wstring const & Style );
-        void setLocale( LocaleSet_t Locale );
+        void setLocale(const LocaleSet_t& Locale);
         void clearStyleLocalePair( void );
         inline StyleLocalePair_t getStyleLocalePair() const{ return m_CurrentStyleLocalePair; };
         inline bool isFull() const
diff --git a/shell/source/win32/ooofilereader/metainforeader.cxx b/shell/source/win32/ooofilereader/metainforeader.cxx
index cc3fdd8..be0c7ee 100644
--- a/shell/source/win32/ooofilereader/metainforeader.cxx
+++ b/shell/source/win32/ooofilereader/metainforeader.cxx
@@ -132,7 +132,7 @@ CMetaInfoReader::~CMetaInfoReader( void )
     @param TagName
     the name of the tag that will be retrieve.
 */
-bool CMetaInfoReader::hasTag( std::wstring TagName ) const
+bool CMetaInfoReader::hasTag(const std::wstring& TagName) const
 {
     return ( m_AllMetaInfo.find(TagName) != m_AllMetaInfo.end());
 }
@@ -157,7 +157,7 @@ std::wstring CMetaInfoReader::getTagData( const std::wstring& TagName)
     @param AttributeName
     the name of the attribute.
 */
-bool CMetaInfoReader::hasTagAttribute( const std::wstring TagName,  std::wstring AttributeName)
+bool CMetaInfoReader::hasTagAttribute(const std::wstring& TagName,  const std::wstring& AttributeName)
 {
     return ( m_AllMetaInfo[TagName].second.find( AttributeName) != m_AllMetaInfo[TagName].second.end() );
 }
@@ -169,9 +169,9 @@ bool CMetaInfoReader::hasTagAttribute( const std::wstring TagName,  std::wstring
     @param AttributeName
     the name of the attribute.
 */
-std::wstring CMetaInfoReader::getTagAttribute( const std::wstring TagName,  std::wstring AttributeName)
+std::wstring CMetaInfoReader::getTagAttribute(const std::wstring& TagName,  const std::wstring& AttributeName)
 {
-    if ( hasTagAttribute( TagName, AttributeName ) )
+    if (hasTagAttribute(TagName, AttributeName))
         return  m_AllMetaInfo[ TagName ].second[AttributeName];
     else
         return EMPTY_STRING;
@@ -181,7 +181,7 @@ std::wstring CMetaInfoReader::getTagAttribute( const std::wstring TagName,  std:
 */
 const LocaleSet_t EN_US_LOCALE( ::std::make_pair( ::std::wstring( L"en" ),  ::std::wstring( L"US" )));
 
-bool isValidLocale ( ::std::wstring Locale )
+bool isValidLocale(const ::std::wstring& Locale)
 {
     return ( Locale.length() == 5 );
 }
diff --git a/shell/source/win32/shlxthandler/shlxthdl.cxx b/shell/source/win32/shlxthandler/shlxthdl.cxx
index 74357bf..80460e8 100644
--- a/shell/source/win32/shlxthandler/shlxthdl.cxx
+++ b/shell/source/win32/shlxthandler/shlxthdl.cxx
@@ -263,7 +263,7 @@ namespace /* private */
 
     /** Approving/Unapproving the Shell Extension, it's important under Windows
         NT/2000/XP, see MSDN: Creating Shell Extension Handlers */
-    HRESULT ApproveShellExtension(CLSID clsid, const std::wstring& Description)
+    HRESULT ApproveShellExtension(const CLSID& clsid, const std::wstring& Description)
     {
         bool bRet = SetRegistryKey(
             HKEY_LOCAL_MACHINE,
@@ -274,7 +274,7 @@ namespace /* private */
         return bRet ? S_OK : E_FAIL;
     }
 
-    HRESULT UnapproveShellExtension(CLSID Clsid)
+    HRESULT UnapproveShellExtension(const CLSID& Clsid)
     {
         HKEY hkey;
 
diff --git a/shell/source/win32/shlxthandler/thumbviewer/thumbviewer.cxx b/shell/source/win32/shlxthandler/thumbviewer/thumbviewer.cxx
index c3f883d..6519a96 100644
--- a/shell/source/win32/shlxthandler/thumbviewer/thumbviewer.cxx
+++ b/shell/source/win32/shlxthandler/thumbviewer/thumbviewer.cxx
@@ -517,7 +517,7 @@ HRESULT STDMETHODCALLTYPE CThumbviewer::GetCurFile(LPOLESTR __RPC_FAR*)
 { return E_NOTIMPL; }
 
 
-Gdiplus::Rect CThumbviewer::CalcScaledAspectRatio(Gdiplus::Rect src, Gdiplus::Rect dest)
+Gdiplus::Rect CThumbviewer::CalcScaledAspectRatio(const Gdiplus::Rect& src, const Gdiplus::Rect& dest)
 {
     Gdiplus::Rect result;
     if (src.Width >= src.Height)
diff --git a/svl/source/inc/passwordcontainer.hxx b/svl/source/inc/passwordcontainer.hxx
index 3f8b9fb..3ddb900 100644
--- a/svl/source/inc/passwordcontainer.hxx
+++ b/svl/source/inc/passwordcontainer.hxx
@@ -291,7 +291,7 @@ bool createUrlRecord(
     ::std::vector< OUString > DecodePasswords( const OUString& aLine, const OUString& aMasterPassword )
                                                         throw(::com::sun::star::uno::RuntimeException);
 
-    OUString EncodePasswords( ::std::vector< OUString > lines, const OUString& aMasterPassword )
+    OUString EncodePasswords(const std::vector< OUString >& lines, const OUString& aMasterPassword )
                                                         throw(::com::sun::star::uno::RuntimeException);
 
 public:
diff --git a/svl/source/passwordcontainer/passwordcontainer.cxx b/svl/source/passwordcontainer/passwordcontainer.cxx
index 59a9379..779cc64 100644
--- a/svl/source/passwordcontainer/passwordcontainer.cxx
+++ b/svl/source/passwordcontainer/passwordcontainer.cxx
@@ -47,7 +47,7 @@ using namespace com::sun::star::task;
 using namespace com::sun::star::ucb;
 
 
-static OUString createIndex( vector< OUString > lines )
+static OUString createIndex(const vector< OUString >& lines)
 {
     OString aResult;
 
@@ -490,9 +490,7 @@ vector< OUString > PasswordContainer::DecodePasswords( const OUString& aLine, co
     throw RuntimeException("Can't decode!" );
 }
 
-
-
-OUString PasswordContainer::EncodePasswords( vector< OUString > lines, const OUString& aMasterPasswd ) throw(RuntimeException)
+OUString PasswordContainer::EncodePasswords(const vector< OUString >& lines, const OUString& aMasterPasswd ) throw(RuntimeException)
 {
     if( !aMasterPasswd.isEmpty() )
     {
@@ -569,7 +567,6 @@ OUString PasswordContainer::EncodePasswords( vector< OUString > lines, const OUS
     throw RuntimeException("Can't encode!" );
 }
 
-
 void PasswordContainer::UpdateVector( const OUString& aURL, list< NamePassRecord >& toUpdate, NamePassRecord& aRecord, bool writeFile ) throw(RuntimeException)
 {
     for( list< NamePassRecord >::iterator aNPIter = toUpdate.begin(); aNPIter != toUpdate.end(); ++aNPIter )
diff --git a/svtools/source/control/ctrlbox.cxx b/svtools/source/control/ctrlbox.cxx
index 8337101..e3576cb 100644
--- a/svtools/source/control/ctrlbox.cxx
+++ b/svtools/source/control/ctrlbox.cxx
@@ -780,11 +780,11 @@ void LineListBox::SelectEntry( sal_uInt16 nStyle, bool bSelect )
 }
 
 void LineListBox::InsertEntry(
-    BorderWidthImpl aWidthImpl, sal_uInt16 nStyle, long nMinWidth,
+    const BorderWidthImpl& rWidthImpl, sal_uInt16 nStyle, long nMinWidth,
     ColorFunc pColor1Fn, ColorFunc pColor2Fn, ColorDistFunc pColorDistFn )
 {
     ImpLineListData* pData = new ImpLineListData(
-        aWidthImpl, nStyle, nMinWidth, pColor1Fn, pColor2Fn, pColorDistFn);
+        rWidthImpl, nStyle, nMinWidth, pColor1Fn, pColor2Fn, pColorDistFn);
     pLineList->push_back( pData );
 }
 
diff --git a/test/source/primitive2dxmldump.cxx b/test/source/primitive2dxmldump.cxx
index 0af7c7c..e1be527 100644
--- a/test/source/primitive2dxmldump.cxx
+++ b/test/source/primitive2dxmldump.cxx
@@ -34,9 +34,9 @@ namespace
 
 const size_t constMaxActionType = 513;
 
-OUString convertColorToString(basegfx::BColor aColor)
+OUString convertColorToString(const basegfx::BColor& rColor)
 {
-    OUString aRGBString = Color(aColor).AsRGBHexString();
+    OUString aRGBString = Color(rColor).AsRGBHexString();
     return "#" + aRGBString;
 }
 
diff --git a/testtools/source/bridgetest/cppobj.cxx b/testtools/source/bridgetest/cppobj.cxx
index e5b96c8..28f13fc 100644
--- a/testtools/source/bridgetest/cppobj.cxx
+++ b/testtools/source/bridgetest/cppobj.cxx
@@ -658,11 +658,11 @@ void Test_Impl::raiseRuntimeExceptionOneway( const OUString & rMsg, const Refere
     throw aExc;
 }
 
-void dothrow2( RuntimeException e )
+void dothrow2(const RuntimeException& e)
 {
     throw e;
 }
-void dothrow( RuntimeException const & e )
+void dothrow(const RuntimeException& e)
 {
 #if defined _MSC_VER
     // currently only for MSVC:
diff --git a/toolkit/source/controls/grid/gridcolumn.cxx b/toolkit/source/controls/grid/gridcolumn.cxx
index 9cc65f5..6a41fc8 100644
--- a/toolkit/source/controls/grid/gridcolumn.cxx
+++ b/toolkit/source/controls/grid/gridcolumn.cxx
@@ -76,7 +76,7 @@ namespace toolkit
     }
 
 
-    void GridColumn::broadcast_changed( sal_Char const * const i_asciiAttributeName, Any i_oldValue, Any i_newValue,
+    void GridColumn::broadcast_changed( sal_Char const * const i_asciiAttributeName, const Any& i_oldValue, const Any& i_newValue,
         ::comphelper::ComponentGuard& i_Guard )
     {
         Reference< XInterface > const xSource( static_cast< ::cppu::OWeakObject* >( this ) );
diff --git a/toolkit/source/controls/grid/gridcolumn.hxx b/toolkit/source/controls/grid/gridcolumn.hxx
index edd7476..a4582d4 100644
--- a/toolkit/source/controls/grid/gridcolumn.hxx
+++ b/toolkit/source/controls/grid/gridcolumn.hxx
@@ -96,8 +96,8 @@ public:
 private:
     void broadcast_changed(
             sal_Char const * const i_asciiAttributeName,
-            ::com::sun::star::uno::Any i_oldValue,
-            ::com::sun::star::uno::Any i_newValue,
+            const css::uno::Any& i_oldValue,
+            const css::uno::Any& i_newValue,
             ::comphelper::ComponentGuard& i_Guard
         );
 
diff --git a/toolkit/source/helper/vclunohelper.cxx b/toolkit/source/helper/vclunohelper.cxx
index 43d34d3..7b80bc7 100644
--- a/toolkit/source/helper/vclunohelper.cxx
+++ b/toolkit/source/helper/vclunohelper.cxx
@@ -440,7 +440,7 @@ vcl::Font VCLUnoHelper::CreateFont( const ::com::sun::star::uno::Reference< ::co
     return aFM;
 }
 
-bool VCLUnoHelper::IsZero( ::com::sun::star::awt::Rectangle rRect )
+bool VCLUnoHelper::IsZero(const css::awt::Rectangle& rRect)
 {
     return ( !rRect.X && !rRect.Y && !rRect.Width && !rRect.Height );
 }
diff --git a/tools/source/generic/b3dtrans.cxx b/tools/source/generic/b3dtrans.cxx
index f370488..d7c22b0 100644
--- a/tools/source/generic/b3dtrans.cxx
+++ b/tools/source/generic/b3dtrans.cxx
@@ -168,10 +168,10 @@ void B3dTransformationSet::PostSetObjectTrans()
     maInvObjectTrans.invert();
 }
 
-void B3dTransformationSet::SetOrientation( basegfx::B3DPoint aVRP, basegfx::B3DVector aVPN, basegfx::B3DVector aVUP)
+void B3dTransformationSet::SetOrientation(const basegfx::B3DPoint& rVRP, const basegfx::B3DVector& rVPN, const basegfx::B3DVector& rVUP)
 {
     maOrientation.identity();
-    Orientation(maOrientation, aVRP, aVPN, aVUP);
+    Orientation(maOrientation, rVRP, rVPN, rVUP);
 
     mbInvTransObjectToEyeValid = false;
     mbObjectToDeviceValid = false;
diff --git a/tools/source/rc/resmgr.cxx b/tools/source/rc/resmgr.cxx
index ebd6fc3..56ad50e 100644
--- a/tools/source/rc/resmgr.cxx
+++ b/tools/source/rc/resmgr.cxx
@@ -1543,9 +1543,9 @@ SimpleResMgr::~SimpleResMgr()
     delete m_pResImpl;
 }
 
-SimpleResMgr* SimpleResMgr::Create( const sal_Char* pPrefixName, LanguageTag aLocale )
+SimpleResMgr* SimpleResMgr::Create(const sal_Char* pPrefixName, const LanguageTag& rLocale)
 {
-    return new SimpleResMgr( pPrefixName, aLocale );
+    return new SimpleResMgr(pPrefixName, rLocale);
 }
 
 bool SimpleResMgr::IsAvailable( RESOURCE_TYPE _resourceType, sal_uInt32 _resourceId )
diff --git a/ucb/source/ucp/cmis/cmis_content.cxx b/ucb/source/ucp/cmis/cmis_content.cxx
index 22f0e99..1fc045a5 100644
--- a/ucb/source/ucp/cmis/cmis_content.cxx
+++ b/ucb/source/ucp/cmis/cmis_content.cxx
@@ -67,7 +67,7 @@ using namespace std;
 
 namespace
 {
-    util::DateTime lcl_boostToUnoTime( boost::posix_time::ptime boostTime )
+    util::DateTime lcl_boostToUnoTime(const boost::posix_time::ptime& boostTime)
     {
         util::DateTime unoTime;
         unoTime.Year = boostTime.date().year();
@@ -169,7 +169,7 @@ namespace
         return aValue;
     }
 
-    libcmis::PropertyPtr lcl_unoToCmisProperty( document::CmisProperty const & prop )
+    libcmis::PropertyPtr lcl_unoToCmisProperty(const document::CmisProperty& prop )
     {
         libcmis::PropertyTypePtr propertyType( new libcmis::PropertyType( ) );
 
@@ -1997,24 +1997,24 @@ namespace cmis
         return results;
     }
 
-    void Content::setCmisProperty( std::string sName, std::string sValue, const uno::Reference< ucb::XCommandEnvironment >& xEnv )
+    void Content::setCmisProperty(const std::string& rName, const std::string& rValue, const uno::Reference< ucb::XCommandEnvironment >& xEnv )
     {
         if ( getObjectType( xEnv ).get( ) )
         {
-            map< string, libcmis::PropertyPtr >::iterator propIt = m_pObjectProps.find( sName );
+            map< string, libcmis::PropertyPtr >::iterator propIt = m_pObjectProps.find(rName);
             vector< string > values;
-            values.push_back( sValue );
+            values.push_back(rValue);
 
             if ( propIt == m_pObjectProps.end( ) && getObjectType( xEnv ).get( ) )
             {
                 map< string, libcmis::PropertyTypePtr > propsTypes = getObjectType( xEnv )->getPropertiesTypes( );
-                map< string, libcmis::PropertyTypePtr >::iterator typeIt = propsTypes.find( sName );
+                map< string, libcmis::PropertyTypePtr >::iterator typeIt = propsTypes.find(rName);
 
                 if ( typeIt != propsTypes.end( ) )
                 {
                     libcmis::PropertyTypePtr propType = typeIt->second;
                     libcmis::PropertyPtr property( new libcmis::Property( propType, values ) );
-                    m_pObjectProps.insert( pair< string, libcmis::PropertyPtr >( sName, property ) );
+                    m_pObjectProps.insert(pair< string, libcmis::PropertyPtr >(rName, property));
                 }
             }
             else if ( propIt != m_pObjectProps.end( ) )
diff --git a/ucb/source/ucp/cmis/cmis_content.hxx b/ucb/source/ucp/cmis/cmis_content.hxx
index 58d818b..d143984 100644
--- a/ucb/source/ucp/cmis/cmis_content.hxx
+++ b/ucb/source/ucp/cmis/cmis_content.hxx
@@ -69,7 +69,7 @@ private:
     std::map< std::string, libcmis::PropertyPtr > m_pObjectProps;
 
     bool isFolder( const com::sun::star::uno::Reference< com::sun::star::ucb::XCommandEnvironment >& xEnv );
-    void setCmisProperty( std::string sName, std::string sValue,
+    void setCmisProperty(const std::string& rName, const std::string& rValue,
             const com::sun::star::uno::Reference< com::sun::star::ucb::XCommandEnvironment >& xEnv );
 
     com::sun::star::uno::Any getBadArgExcept();
diff --git a/vcl/source/control/longcurr.cxx b/vcl/source/control/longcurr.cxx
index 027fb39..5f081be 100644
--- a/vcl/source/control/longcurr.cxx
+++ b/vcl/source/control/longcurr.cxx
@@ -330,9 +330,9 @@ OUString LongCurrencyFormatter::GetCurrencySymbol() const
     return !maCurrencySymbol.isEmpty() ? maCurrencySymbol : GetLocaleDataWrapper().getCurrSymbol();
 }
 
-void LongCurrencyFormatter::SetValue( BigInt nNewValue )
+void LongCurrencyFormatter::SetValue(const BigInt& rNewValue)
 {
-    SetUserValue( nNewValue );
+    SetUserValue(rNewValue);
     mnFieldValue = mnLastValue;
     SetEmptyFieldValueData( false );
 }
@@ -407,15 +407,15 @@ void LongCurrencyFormatter::ReformatAll()
     Reformat();
 }
 
-void LongCurrencyFormatter::SetMin( BigInt nNewMin )
+void LongCurrencyFormatter::SetMin(const BigInt& rNewMin)
 {
-    mnMin = nNewMin;
+    mnMin = rNewMin;
     ReformatAll();
 }
 
-void LongCurrencyFormatter::SetMax( BigInt nNewMax )
+void LongCurrencyFormatter::SetMax(const BigInt& rNewMax)
 {
-    mnMax = nNewMax;
+    mnMax = rNewMax;
     ReformatAll();
 }
 
@@ -435,7 +435,7 @@ void LongCurrencyFormatter::SetDecimalDigits( sal_uInt16 nDigits )
 }
 
 
-void ImplNewLongCurrencyFieldValue( LongCurrencyField* pField, BigInt nNewValue )
+void ImplNewLongCurrencyFieldValue(LongCurrencyField* pField, const BigInt& rNewValue)
 {
     Selection aSelect = pField->GetSelection();
     aSelect.Justify();
@@ -443,7 +443,7 @@ void ImplNewLongCurrencyFieldValue( LongCurrencyField* pField, BigInt nNewValue
     bool bLastSelected = aSelect.Max() == aText.getLength();
 
     BigInt nOldLastValue  = pField->mnLastValue;
-    pField->SetUserValue( nNewValue );
+    pField->SetUserValue(rNewValue);
     pField->mnLastValue  = nOldLastValue;
 
     if ( bLastSelected )
diff --git a/vcl/source/opengl/OpenGLContext.cxx b/vcl/source/opengl/OpenGLContext.cxx
index f0bc5b4..352b630 100644
--- a/vcl/source/opengl/OpenGLContext.cxx
+++ b/vcl/source/opengl/OpenGLContext.cxx
@@ -180,7 +180,7 @@ static LRESULT CALLBACK WndProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM l
     }
 }
 
-int InitTempWindow(HWND *hwnd, int width, int height, PIXELFORMATDESCRIPTOR inPfd, GLWindow glWin)
+int InitTempWindow(HWND *hwnd, int width, int height, const PIXELFORMATDESCRIPTOR& inPfd, GLWindow glWin)
 {
     PIXELFORMATDESCRIPTOR  pfd = inPfd;
     int  pfmt;
@@ -260,7 +260,7 @@ bool WGLisExtensionSupported(const char *extension)
     }
 }
 
-bool InitMultisample(PIXELFORMATDESCRIPTOR pfd, int& rPixelFormat,
+bool InitMultisample(const PIXELFORMATDESCRIPTOR& pfd, int& rPixelFormat,
         bool bUseDoubleBufferedRendering, bool bRequestVirtualDevice)
 {
     HWND hWnd = NULL;
diff --git a/vcl/source/window/taskpanelist.cxx b/vcl/source/window/taskpanelist.cxx
index 23b9648..2089172 100644
--- a/vcl/source/window/taskpanelist.cxx
+++ b/vcl/source/window/taskpanelist.cxx
@@ -150,7 +150,7 @@ bool TaskPaneList::IsInList( vcl::Window *pWindow )
         return false;
 }
 
-bool TaskPaneList::HandleKeyEvent( KeyEvent aKeyEvent )
+bool TaskPaneList::HandleKeyEvent(const KeyEvent& rKeyEvent)
 {
 
     // F6 cycles through everything and works always
@@ -162,7 +162,7 @@ bool TaskPaneList::HandleKeyEvent( KeyEvent aKeyEvent )
 
     // Since the design of Ctrl-Tab looks to be inconsistent ( non-modal dialogs are not reachable
     // and the shortcut conflicts with tab-control shortcut ), it is no more supported
-    vcl::KeyCode aKeyCode = aKeyEvent.GetKeyCode();
+    vcl::KeyCode aKeyCode = rKeyEvent.GetKeyCode();
     bool bForward = !aKeyCode.IsShift();
     if( aKeyCode.GetCode() == KEY_F6 && ! aKeyCode.IsMod2() ) // F6
     {
diff --git a/vcl/source/window/toolbox.cxx b/vcl/source/window/toolbox.cxx
index 1a6179e..cb2b3f5 100644
--- a/vcl/source/window/toolbox.cxx
+++ b/vcl/source/window/toolbox.cxx
@@ -2859,7 +2859,7 @@ void ToolBox::ImplDrawSpin( bool bUpperIn, bool bLowerIn )
                         bUpperIn, bLowerIn, bTmpUpper, bTmpLower, !mbHorz );
 }
 
-void ToolBox::ImplDrawSeparator( sal_uInt16 nPos, Rectangle rRect )
+void ToolBox::ImplDrawSeparator(sal_uInt16 nPos, const Rectangle& rRect)
 {
     bool bNativeOk = false;
     ImplToolItem* pItem = &mpData->m_aItems[nPos];
diff --git a/vcl/workben/vcldemo.cxx b/vcl/workben/vcldemo.cxx
index f02ac03..70e4ac8 100644
--- a/vcl/workben/vcldemo.cxx
+++ b/vcl/workben/vcldemo.cxx
@@ -199,7 +199,7 @@ public:
         }
     }
 
-    void drawBackground(OutputDevice &rDev, Rectangle r)
+    void drawBackground(OutputDevice &rDev, const Rectangle& r)
     {
         rDev.Erase();
         Gradient aGradient;
@@ -627,7 +627,7 @@ public:
 
         // Simulate Page Borders rendering - which ultimately should
         // be done with a shader / gradient
-        void SimulateBorderStretch(OutputDevice &rDev, Rectangle r)
+        void SimulateBorderStretch(OutputDevice &rDev, const Rectangle& r)
         {
             static BitmapEx aPageShadowMask("sw/res/page-shadow-mask.png");
 
@@ -760,7 +760,7 @@ public:
             RENDER_AS_ALPHA_OUTDEV
         };
 
-        void SizeAndRender(OutputDevice &rDev, Rectangle r, RenderType eType,
+        void SizeAndRender(OutputDevice &rDev, const Rectangle& r, RenderType eType,
                            const RenderContext &rCtx)
         {
             VirtualDevice *pNested;
diff --git a/xmloff/source/chart/SchXMLAxisContext.cxx b/xmloff/source/chart/SchXMLAxisContext.cxx
index f7192cf..079dbb6 100644
--- a/xmloff/source/chart/SchXMLAxisContext.cxx
+++ b/xmloff/source/chart/SchXMLAxisContext.cxx
@@ -122,16 +122,16 @@ SchXMLAxisContext::SchXMLAxisContext( SchXMLImportHelper& rImpHelper,
 SchXMLAxisContext::~SchXMLAxisContext()
 {}
 
-static Reference< chart::XAxis > lcl_getChartAxis( SchXMLAxis aCurrentAxis, const Reference< chart::XDiagram > xDiagram )
+static Reference< chart::XAxis > lcl_getChartAxis(const SchXMLAxis& rCurrentAxis, const Reference< chart::XDiagram > xDiagram )
 {
     Reference< chart::XAxis > xAxis;
     Reference< chart::XAxisSupplier > xAxisSuppl( xDiagram, uno::UNO_QUERY );
     if( !xAxisSuppl.is() )
         return xAxis;
-    if( aCurrentAxis.nAxisIndex == 0 )
-        xAxis = xAxisSuppl->getAxis(aCurrentAxis.eDimension);
+    if( rCurrentAxis.nAxisIndex == 0 )
+        xAxis = xAxisSuppl->getAxis(rCurrentAxis.eDimension);
     else
-        xAxis = xAxisSuppl->getSecondaryAxis(aCurrentAxis.eDimension);
+        xAxis = xAxisSuppl->getSecondaryAxis(rCurrentAxis.eDimension);
     return xAxis;
 }
 


More information about the Libreoffice-commits mailing list
diff --git a/setup_native/source/win32/customactions/shellextensions/vistaspecial.cxx b/setup_native/source/win32/customactions/shellextensions/vistaspecial.cxx
index ab039e2..162d54d 100644
--- a/setup_native/source/win32/customactions/shellextensions/vistaspecial.cxx
+++ b/setup_native/source/win32/customactions/shellextensions/vistaspecial.cxx
@@ -63,7 +63,6 @@ static inline void OutputDebugStringFormat( LPCSTR, ... )
 }
 #endif
 
-
 static std::_tstring GetMsiProperty( MSIHANDLE handle, const std::_tstring& sProperty )
 {
     std::_tstring result;
@@ -82,14 +81,14 @@ static std::_tstring GetMsiProperty( MSIHANDLE handle, const std::_tstring& sPro
     return result;
 }
 
-static BOOL RemoveCompleteDirectory( std::_tstring sPath )
+static BOOL RemoveCompleteDirectory(const std::_tstring& rPath)
 {
     bool bDirectoryRemoved = true;
 
-    std::_tstring sPattern = sPath + TEXT("\\") + TEXT("*.*");
+    std::_tstring sPattern = rPath + TEXT("\\") + TEXT("*.*");
     WIN32_FIND_DATA aFindData;
 
     // Finding all content in sPath
 
     HANDLE hFindContent = FindFirstFile( sPattern.c_str(), &aFindData );
 
@@ -106,7 +105,7 @@ static BOOL RemoveCompleteDirectory( std::_tstring sPath )
             if (( strcmp(sFileName.c_str(),sCurrentDir.c_str()) != 0 ) &&
                 ( strcmp(sFileName.c_str(),sParentDir.c_str()) != 0 ))
             {
-                std::_tstring sCompleteFileName = sPath + TEXT("\\") + sFileName;
+                std::_tstring sCompleteFileName = rPath + TEXT("\\") + sFileName;
 
                 if ( aFindData.dwFileAttributes == FILE_ATTRIBUTE_DIRECTORY )
                 {
@@ -129,7 +128,7 @@ static BOOL RemoveCompleteDirectory( std::_tstring sPath )
         // -> first removing content -> closing handle -> remove empty directory
 
 
-        if( !( RemoveDirectory(sPath.c_str()) ) )
+        if( !( RemoveDirectory(rPath.c_str()) ) )
         {
             bDirectoryRemoved = false;
         }
@@ -138,8 +137,6 @@ static BOOL RemoveCompleteDirectory( std::_tstring sPath )
     return bDirectoryRemoved;
 }
 
-
-
 extern "C" UINT __stdcall RenamePrgFolder( MSIHANDLE handle )
 {
     std::_tstring sOfficeInstallPath = GetMsiProperty(handle, TEXT("INSTALLLOCATION"));
@@ -82,14 +81,14 @@ static std::_tstring GetMsiProperty( MSIHANDLE handle, const std::_tstring& sPro
     WIN32_FIND_DATA aFindData;
 
-    // Finding all content in sPath
+    // Finding all content in rPath
 
     HANDLE hFindContent = FindFirstFile( sPattern.c_str(), &aFindData );